@@ -272,6 +272,14 @@ void TLevelWriterAvi::searchForCodec() {
     for (int bpp = 32; (bpp >= 24) && !found; bpp -= 8) {
       inFmt.bmiHeader.biBitCount = bpp;
       for (int i = 0; ICInfo(fccType, i, &icinfo); i++) {
+        // Skip blacklisted DLLs
+        char driver[2048];
+        WideChar2Char(icinfo.szDriver, driver, sizeof(driver));
+        if (TSystem::isDLLBlackListed(
+                QString::fromStdString(std::string(driver)))) {
+          continue;
+        }
+
         hic = ICOpen(icinfo.fccType, icinfo.fccHandler, ICMODE_COMPRESS);
 
         ICGetInfo(hic, &icinfo,
@@ -720,7 +728,11 @@ TLevelReaderAvi::TLevelReaderAvi(const TFilePath &path)
     ICINFO icinfo;
     memset(&icinfo, 0, sizeof(ICINFO));
     ICInfo(ICTYPE_VIDEO, si.fccHandler, &icinfo);
-    m_hic = ICOpen(icinfo.fccType, icinfo.fccHandler, ICMODE_DECOMPRESS);
+
+    char driver[2048];
+    WideChar2Char(icinfo.szDriver, driver, sizeof(driver));
+    if (!TSystem::isDLLBlackListed(driver))
+      m_hic = ICOpen(icinfo.fccType, icinfo.fccHandler, ICMODE_DECOMPRESS);
     if (!m_hic) {
       m_hic = findCandidateDecompressor();
       if (!m_hic)
@@ -786,6 +798,14 @@ HIC TLevelReaderAvi::findCandidateDecompressor() {
     info.dwSize = sizeof(
         ICINFO);  // I don't think this is necessary, but just in case....
 
+    // Skip blacklisted DLLs
+    char driver[2048];
+    WideChar2Char(info.szDriver, driver, sizeof(driver));
+    if (TSystem::isDLLBlackListed(
+            QString::fromStdString(std::string(driver)))) {
+      continue;
+    }
+
     HIC hic = ICOpen(info.fccType, info.fccHandler, ICMODE_DECOMPRESS);
 
     if (!hic) continue;
@@ -970,16 +990,16 @@ TImageP TLevelReaderAvi::load(int frameIndex) {
 int TLevelReaderAvi::readFrameFromStream(void *bufferOut, DWORD &bufferSize,
                                          int frameIndex) const {
   assert(bufferOut && bufferSize > 0);
-  LONG bytesReaded   = 0;
-  LONG samplesReaded = 0;
+  LONG bytesReaded = 0;
+  LONG samplesRead = 0;
 
   int rc = AVIStreamRead(m_videoStream, frameIndex, 1, bufferOut, bufferSize,
-                         &bytesReaded, &samplesReaded);
+                         &bytesReaded, &samplesRead);
   if (!rc) {
-    assert(samplesReaded == 1);  // deve aver letto un frame!!!
+    assert(samplesRead == 1);  // must have read a frame!!!
     assert(bytesReaded <=
-           (LONG)bufferSize);  // deve aver letto un numero di byte
-    // minore o uguale di quello che ci aspettiamo
+           (LONG)bufferSize);  // must have read a number of bytes
+    // less than or equal to what we expect
     bufferSize = bytesReaded;
   }
   return rc;
@@ -1133,6 +1153,14 @@ Tiio::AviWriterProperties::AviWriterProperties() : m_codec("Codec") {
           break;
         }
 
+        // Skip blacklisted DLLs
+        char driver[2048];
+        WideChar2Char(icinfo.szDriver, driver, sizeof(driver));
+        if (TSystem::isDLLBlackListed(
+                QString::fromStdString(std::string(driver)))) {
+          continue;
+        }
+
         auto const hic =
             safe_ICOpen(icinfo.fccType, icinfo.fccHandler, ICMODE_QUERY);
         if (!hic) {
