@@ -27,7 +27,7 @@ class Raster32PMyPaintSurface : public mypaint::Surface {
 private:
   class Internal;
 
-  TRaster32P m_ras;
+  TRaster32P ras;
   RasterController *controller;
   Internal *internal;
 
@@ -80,6 +80,8 @@ public:
 
   bool getAntialiasing() const;
   void setAntialiasing(bool value);
+
+  RasterController *getController() const { return controller; }
 };
 
 //=======================================================
@@ -93,19 +95,20 @@ private:
   struct Params {
     union {
       struct {
-        double x, y, pressure, time;
+        double x, y, pressure, tx, ty, time;
       };
       struct {
-        double values[4];
+        double values[6];
       };
     };
 
     inline explicit Params(double x = 0.0, double y = 0.0,
-                           double pressure = 0.0, double time = 0.0)
-        : x(x), y(y), pressure(pressure), time(time) {}
+                           double pressure = 0.0, double tx = 0.0,
+                           double ty = 0.0, double time = 0.0)
+        : x(x), y(y), pressure(pressure), tx(tx), ty(ty), time(time) {}
 
     inline void setMedian(Params &a, Params &b) {
-      for (int i  = 0; i < (int)sizeof(values) / sizeof(values[0]); ++i)
+      for (int i = 0; i < (int)sizeof(values) / sizeof(values[0]); ++i)
         values[i] = 0.5 * (a.values[i] + b.values[i]);
     }
   };
@@ -116,21 +119,29 @@ private:
 
   TRaster32P m_ras;
   Raster32PMyPaintSurface m_mypaintSurface;
-  mypaint::Brush brush;
+  mypaint::Brush m_brush;
 
-  bool reset;
-  Params previous, current;
+  bool m_reset;
+  Params m_previous, m_current;
+  bool m_interpolation;
 
 public:
   MyPaintToonzBrush(const TRaster32P &ras, RasterController &controller,
-                    const mypaint::Brush &brush);
+                    const mypaint::Brush &brush, bool interpolation = false);
   void beginStroke();
+  void strokeTo(const TPointD &position, double pressure, const TPointD &tilt,
+                double dtime);
   void endStroke();
-  void strokeTo(const TPointD &p, double pressure, double dtime);
 
   // colormapped
   void updateDrawing(const TRasterCM32P rasCM, const TRasterCM32P rasBackupCM,
                      const TRect &bbox, int styleId, bool lockAlpha) const;
+
+  const TRaster32P &getRaster() const { return m_ras; }
+  RasterController &getController() {
+    return *m_mypaintSurface.getController();
+  }
+  const mypaint::Brush &getBrush() const { return m_brush; }
 };
 
 #endif  // T_BLUREDBRUSH
