@@ -310,6 +310,21 @@ void ExpressionReferenceManager::onSceneSwitched() {
 
 //-----------------------------------------------------------------------------
 
+void ExpressionReferenceManager::refreshXsheetRefInfo(TXsheet* xsh) {
+  xsh->setObserver(this);
+  m_model->refreshData(xsh);
+  xsh->getExpRefMonitor()->clearAll();
+  for (int i = 0; i < m_model->getStageObjectsChannelCount(); i++) {
+    checkRef(m_model->getStageObjectChannel(i), xsh);
+  }
+  for (int i = 0; i < m_model->getFxsChannelCount(); i++) {
+    checkRef(m_model->getFxChannel(i), xsh);
+  }
+  onXsheetSwitched();
+}
+
+//-----------------------------------------------------------------------------
+
 void ExpressionReferenceManager::onXsheetSwitched() {
   TXsheet* xsh = TApp::instance()->getCurrentXsheet()->getXsheet();
   xsh->setObserver(this);
@@ -772,7 +787,8 @@ void ExpressionReferenceManager::transferReference(
 
   // 1. create 3 tables for replacing; column indices, parameter pointers, and
   // expression texts. Note that moving columns in the same xsheet does not need
-  // to replace the paramter pointers since they are swapped along with columns.
+  // to replace the parameter pointers since they are swapped along with
+  // columns.
   QMap<int, int> colIdReplaceTable;
   QMap<TDoubleParam*, TDoubleParam*> curveReplaceTable;
   std::map<std::string, std::string> exprReplaceTable;
@@ -796,7 +812,7 @@ void ExpressionReferenceManager::transferReference(
         exprReplaceTable[getPhrase(fromId, ph)] = getPhrase(toId, ph);
     }
     if (sameXSheet) {
-      // the paramter pointers are already swapped when moving columns in the
+      // the parameter pointers are already swapped when moving columns in the
       // same xsheet curveReplaceTable will be used just for parameter list to
       // be modified
       TStageObject* toObj =
@@ -971,7 +987,7 @@ void ExpressionReferenceManager::transferReference(
 }
 
 //----------------------------------------------------------------------------
-// open warning popup if there is any paramters which is ignored (i.e. the
+// open warning popup if there is any parameters which is ignored (i.e. the
 // reference is lost and user hasn't touch yet)
 bool ExpressionReferenceManager::askIfParamIsIgnoredOnSave(bool saveSubXsheet) {
   // return if the preference option is off
