@@ -20,9 +20,10 @@
 // TnzCore includes
 #include "tlevel_io.h"
 #include "tproperty.h"
-#include "movsettings.h"
 #include "timageinfo.h"
 #include "tfiletype.h"
+#include "tiio.h"
+#include "movsettings.h"
 
 // Qt includes
 #include <QComboBox>
@@ -403,9 +404,10 @@ void FormatSettingsPopup::onPaddingCBChanged() {
 bool openFormatSettingsPopup(QWidget *parent, const std::string &format,
                              TPropertyGroup *props, TFrameId *tmplFId,
                              bool forInput, const TFilePath &levelPath) {
-  if (format == "mov" || format == "3gp")  // trattato diversamente; il format
-                                           // popup dei mov e' quello di
-                                           // quicktime
+  bool quicktime = (format == "mov" || format == "3gp") && Tiio::useQuicktime();
+  if (quicktime)  // trattato diversamente; il format
+                  // popup dei mov e' quello di
+                  // quicktime
   {
     // gmt 26/9/07. con la penna capita spesso di premere ripetutamente il
     // bottone.
