@@ -29,11 +29,13 @@
 #define MI_NewVectorLevel "MI_NewVectorLevel"
 #define MI_NewToonzRasterLevel "MI_NewToonzRasterLevel"
 #define MI_NewRasterLevel "MI_NewRasterLevel"
+#define MI_NewMetaLevel "MI_NewMetaLevel"
 #define MI_LoadLevel "MI_LoadLevel"
 #define MI_LoadFolder "MI_LoadFolder"
 #define MI_SaveLevel "MI_SaveLevel"
 #define MI_SaveLevelAs "MI_SaveLevelAs"
 #define MI_ExportLevel "MI_ExportLevel"
+#define MI_ExportAllLevels "MI_ExportAllLevels"
 #define MI_SavePaletteAs "MI_SavePaletteAs"
 #define MI_OverwritePalette "MI_OverwritePalette"
 #define MI_LoadColorModel "MI_LoadColorModel"
@@ -54,7 +56,9 @@
 #define MI_ClonePreview "MI_ClonePreview"
 #define MI_FreezePreview "MI_FrezzePreview"
 #define MI_SavePreviewedFrames "MI_SavePreviewedFrames"
-//#define MI_SavePreview         "MI_SavePreview"
+// #define MI_SavePreview         "MI_SavePreview"
+#define MI_ToggleViewerPreview "MI_ToggleViewerPreview"
+#define MI_ToggleViewerSubCameraPreview "MI_ToggleViewerSubCameraPreview"
 #define MI_Print "MI_Print"
 #define MI_Preferences "MI_Preferences"
 #define MI_SavePreset "MI_SavePreset"
@@ -83,8 +87,9 @@
 #define MI_CanvasSize "MI_CanvasSize"
 #define MI_RemoveUnused "MI_RemoveUnused"
 
-//#define MI_OpenCurrentScene  "MI_OpenCurrentScene"
+// #define MI_OpenCurrentScene  "MI_OpenCurrentScene"
 #define MI_OpenFileBrowser "MI_OpenFileBrowser"
+#define MI_OpenPreproductionBoard "MI_OpenPreproductionBoard"
 #define MI_OpenFileViewer "MI_OpenFileViewer"
 #define MI_OpenFilmStrip "MI_OpenFilmStrip"
 #define MI_OpenPalette "MI_OpenPalette"
@@ -96,7 +101,7 @@
 #define MI_OpenToolOptionBar "MI_OpenToolOptionBar"
 #define MI_OpenLevelView "MI_OpenLevelView"
 #define MI_OpenStopMotionPanel "MI_OpenStopMotionPanel"
-//#define MI_OpenExport "MI_OpenExport"
+// #define MI_OpenExport "MI_OpenExport"
 #define MI_BrightnessAndContrast "MI_BrightnessAndContrast"
 #define MI_Antialias "MI_Antialias"
 #define MI_AdjustLevels "MI_AdjustLevels"
@@ -189,7 +194,9 @@
 #define MI_EditShift "MI_EditShift"
 #define MI_NoShift "MI_NoShift"
 #define MI_ResetShift "MI_ResetShift"
+#define MI_ShowShiftOrigin "MI_ShowShiftOrigin"
 #define MI_Histogram "MI_Histogram"
+#define MI_ViewerHistogram "MI_ViewerHistogram"
 #define MI_FxParamEditor "MI_FxParamEditor"
 
 #define MI_Link "MI_Link"
@@ -207,6 +214,7 @@
 #define MI_PrevStep "MI_PrevStep"
 #define MI_NextKeyframe "MI_NextKeyframe"
 #define MI_PrevKeyframe "MI_PrevKeyframe"
+#define MI_ToggleBlankFrames "MI_ToggleBlankFrames"
 
 #define MI_RedChannel "MI_RedChannel"
 #define MI_GreenChannel "MI_GreenChannel"
@@ -231,11 +239,13 @@
 #define MI_ResetRoomLayout "MI_ResetRoomLayout"
 #define MI_MaximizePanel "MI_MaximizePanel"
 #define MI_FullScreenWindow "MI_FullScreenWindow"
+#define MI_SeeThroughWindow "MI_SeeThroughWindow"
 #define MI_OnionSkin "MI_OnionSkin"
 #define MI_ZeroThick "MI_ZeroThick"
 #define MI_CursorOutline "MI_CursorOutline"
+#define MI_ViewerIndicator "MI_ViewerIndicator"
 
-//#define MI_LoadResourceFile       "MI_LoadResourceFile"
+// #define MI_LoadResourceFile       "MI_LoadResourceFile"
 #define MI_DuplicateFile "MI_DuplicateFile"
 #define MI_ViewFile "MI_ViewFile"
 #define MI_ConvertFiles "MI_ConvertFiles"
@@ -257,6 +267,7 @@
 #define MI_CollectAssets "MI_CollectAssets"
 #define MI_ImportScenes "MI_ImportScenes"
 #define MI_ExportScenes "MI_ExportScenes"
+#define MI_ExportCurrentScene "MI_ExportCurrentScene"
 
 #define MI_SelectRowKeyframes "MI_SelectRowKeyframes"
 #define MI_SelectColumnKeyframes "MI_SelectColumnKeyframes"
@@ -305,6 +316,7 @@
 #define MI_UnlockAllColumns "MI_UnlockAllColumns"
 #define MI_ToggleColumnLocks "MI_ToggleColumnLocks"
 #define MI_ToggleXSheetToolbar "MI_ToggleXSheetToolbar"
+#define MI_ToggleXsheetBreadcrumbs "MI_ToggleXsheetBreadcrumbs"
 #define MI_FoldColumns "MI_FoldColumns"
 #define MI_ToggleXsheetCameraColumn "MI_ToggleXsheetCameraColumn"
 #define MI_ToggleCurrentTimeIndicator "MI_ToggleCurrentTimeIndicator"
@@ -356,11 +368,17 @@
 #define MI_TypeBoldOblique "MI_TypeBoldOblique"
 #define MI_TypeBold "MI_TypeBold"
 
+#define MI_PaintBrushNextMode "MI_PaintBrushNextMode"
+#define MI_PaintBrushAreas "MI_PaintBrushAreas"
+#define MI_PaintBrushLines "MI_PaintBrushLines"
+#define MI_PaintBrushLinesAndAreas "MI_PaintBrushLinesAndAreas"
+
 #define MI_FillNextType "MI_FillNextType"
 #define MI_FillNormal "MI_FillNormal"
 #define MI_FillRectangular "MI_FillRectangular"
 #define MI_FillFreehand "MI_FillFreehand"
 #define MI_FillPolyline "MI_FillPolyline"
+#define MI_FillFreepick "MI_FillFreepick"
 #define MI_FillNextMode "MI_FillNextMode"
 #define MI_FillAreas "MI_FillAreas"
 #define MI_FillLines "MI_FillLines"
@@ -372,6 +390,7 @@
 #define MI_EraserFreehand "MI_EraserFreehand"
 #define MI_EraserPolyline "MI_EraserPolyline"
 #define MI_EraserSegment "MI_EraserSegment"
+#define MI_EraserMultiArc "MI_EraserMultiArc"
 
 #define MI_TapeNextType "MI_TapeNextType"
 #define MI_TapeNormal "MI_TapeNormal"
@@ -454,8 +473,11 @@
 #define MI_FlipPrevGuideStroke "MI_FlipPrevGuideStroke"
 
 #define MI_ExportXDTS "MI_ExportXDTS"
+#define MI_ExportOCA "MI_ExportOCA"
+#define MI_ImportOCA "MI_ImportOCA"
 #define MI_ExportTvpJson "MI_ExportTvpJson"
 #define MI_ExportXsheetPDF "MI_ExportXsheetPDF"
+#define MI_ExportCameraTrack "MI_ExportCameraTrack"
 
 // mark id is added for each actual command (i.g. MI_SetCellMark1)
 #define MI_SetCellMark "MI_SetCellMark"
@@ -463,4 +485,17 @@
 #define MI_ZoomInAndFitPanel "MI_ZoomInAndFitPanel"
 #define MI_ZoomOutAndFitPanel "MI_ZoomOutAndFitPanel"
 
+#define MI_OpenCustomPanels "MI_OpenCustomPanels"
+#define MI_CustomPanelEditor "MI_CustomPanelEditor"
+
+#define MI_ConvertTZPInFolder "MI_ConvertTZPInFolder"
+
+// Navigation tags
+#define MI_ToggleTaggedFrame "MI_ToggleTaggedFrame"
+#define MI_EditTaggedFrame "MI_EditTaggedFrame"
+#define MI_NextTaggedFrame "MI_NextTaggedFrame"
+#define MI_PrevTaggedFrame "MI_PrevTaggedFrame"
+#define MI_ClearTags "MI_ClearTags"
+
+#define MI_OpenLocator "MI_OpenLocator"
 #endif
