@@ -7,6 +7,7 @@
 #include "mainwindow.h"
 #include "tenv.h"
 #include "saveloadqsettings.h"
+#include "custompanelmanager.h"
 
 #include "toonzqt/gutil.h"
 
@@ -33,9 +34,12 @@
 #include <QDesktopWidget>
 #include <QDialog>
 #include <QLineEdit>
+#include <QTextEdit>
 #include <QScreen>
+#include <QDebug>
 
 extern TEnv::StringVar EnvSafeAreaName;
+extern TEnv::IntVar EnvViewerPreviewBehavior;
 
 //=============================================================================
 // TPanel
@@ -121,7 +125,8 @@ void TPanel::enterEvent(QEvent *event) {
   if (w) {
     // grab the focus, unless a line-edit is focused currently
     QWidget *focusWidget = qApp->focusWidget();
-    if (focusWidget && dynamic_cast<QLineEdit *>(focusWidget)) {
+    if (focusWidget && (dynamic_cast<QLineEdit *>(focusWidget) ||
+                        dynamic_cast<QTextEdit *>(focusWidget))) {
       event->accept();
       return;
     }
@@ -235,26 +240,21 @@ void TPanel::zoomContentsAndFitGeometry(bool forward) {
 TPanelTitleBarButton::TPanelTitleBarButton(QWidget *parent,
                                            const QString &standardPixmapName)
     : QWidget(parent)
-    , m_standardPixmap(standardPixmapName)
     , m_standardPixmapName(standardPixmapName)
     , m_rollover(false)
     , m_pressed(false)
     , m_buttonSet(0)
     , m_id(0) {
-  setFixedSize(m_standardPixmap.size());
-}
+  setMouseTracking(true);
 
-//-----------------------------------------------------------------------------
+  // Determine button size
+  m_baseSize = QSize(20, 18);
+  if (m_standardPixmapName.contains("preview", Qt::CaseInsensitive)) {
+    m_baseSize = QSize(30, 18);
+  }
 
-TPanelTitleBarButton::TPanelTitleBarButton(QWidget *parent,
-                                           const QPixmap &standardPixmap)
-    : QWidget(parent)
-    , m_standardPixmap(standardPixmap)
-    , m_rollover(false)
-    , m_pressed(false)
-    , m_buttonSet(0)
-    , m_id(0) {
-  setFixedSize(m_standardPixmap.size() / m_standardPixmap.devicePixelRatio());
+  // Set initial size
+  setFixedSize(m_baseSize);
 }
 
 //-----------------------------------------------------------------------------
@@ -277,25 +277,109 @@ void TPanelTitleBarButton::setPressed(bool pressed) {
 
 //-----------------------------------------------------------------------------
 
+void TPanelTitleBarButton::setOffColor(const QColor &color) {
+  if (m_offColor != color) {
+    m_offColor = color;
+  }
+}
+
+QColor TPanelTitleBarButton::getOffColor() const { return m_offColor; }
+
+//-----------------------------------------------------------------------------
+
+void TPanelTitleBarButton::setOverColor(const QColor &color) {
+  if (m_overColor != color) {
+    m_overColor = color;
+  }
+}
+
+QColor TPanelTitleBarButton::getOverColor() const { return m_overColor; }
+
+//-----------------------------------------------------------------------------
+
+void TPanelTitleBarButton::setPressedColor(const QColor &color) {
+  if (m_pressedColor != color) {
+    m_pressedColor = color;
+  }
+}
+
+QColor TPanelTitleBarButton::getPressedColor() const { return m_pressedColor; }
+
+//-----------------------------------------------------------------------------
+
+void TPanelTitleBarButton::setFreezeColor(const QColor &color) {
+  if (m_freezeColor != color) {
+    m_freezeColor = color;
+  }
+}
+
+QColor TPanelTitleBarButton::getFreezeColor() const { return m_freezeColor; }
+
+//-----------------------------------------------------------------------------
+
+void TPanelTitleBarButton::setPreviewColor(const QColor &color) {
+  if (m_previewColor != color) {
+    m_previewColor = color;
+  }
+}
+
+QColor TPanelTitleBarButton::getPreviewColor() const { return m_previewColor; }
+
+//-----------------------------------------------------------------------------
+
 void TPanelTitleBarButton::paintEvent(QPaintEvent *event) {
-  // Set unique pressed colors if filename contains the following words:
-  QColor bgColor = getPressedColor();
-  if (m_standardPixmapName.contains("freeze", Qt::CaseInsensitive))
-    bgColor = getFreezeColor();
-  if (m_standardPixmapName.contains("preview", Qt::CaseInsensitive))
-    bgColor = getPreviewColor();
+  if (m_standardPixmapName.isEmpty()) return;
 
-  QPixmap panePixmap    = recolorPixmap(svgToPixmap(m_standardPixmapName));
-  QPixmap panePixmapOff = compositePixmap(panePixmap, 0.8);
-  QPixmap panePixmapOver =
-      compositePixmap(panePixmap, 1, QSize(), 0, 0, getOverColor());
-  QPixmap panePixmapOn = compositePixmap(panePixmap, 1, QSize(), 0, 0, bgColor);
+  QPainter p(this);
 
-  QPainter painter(this);
-  painter.drawPixmap(
-      0, 0,
-      m_pressed ? panePixmapOn : m_rollover ? panePixmapOver : panePixmapOff);
-  painter.end();
+  // Determine icon state
+  QIcon::Mode mode   = m_rollover ? QIcon::Active : QIcon::Normal;
+  QIcon::State state = m_pressed ? QIcon::On : QIcon::Off;
+
+  // Get DPR and sizes
+  qreal dpr    = getDevicePixelRatio(this);
+  auto &tm     = ThemeManager::getInstance();
+  QSize iconSz = tm.getIconSize(m_standardPixmapName);
+  QSize physSz = iconSz * dpr;
+  QSize btnSz  = size() * dpr;
+
+  // Cache key with DPR
+  QString cacheKey =
+      generateCacheKey(m_standardPixmapName, btnSz, mode, state) +
+      QString::number(dpr);
+
+  // Try cache first
+  QPixmap finalPm = getFromPixmapCache(cacheKey);
+  if (finalPm.isNull()) {
+    QPixmap pm = SvgIconEngine(m_standardPixmapName, false, dpr, iconSz)
+                     .pixmap(iconSz, mode, state);
+    pm.scaled(iconSz, Qt::KeepAspectRatio);
+
+    if (!pm.isNull()) {
+      QColor bgColor = getOffColor();
+      if (m_pressed) {
+        if (m_standardPixmapName.contains("freeze")) {
+          bgColor = getFreezeColor();
+        } else if (m_standardPixmapName.contains("preview")) {
+          bgColor = getPreviewColor();
+        } else {
+          bgColor = getPressedColor();
+        }
+      } else if (m_rollover) {
+        bgColor = getOverColor();
+      }
+
+      pm.setDevicePixelRatio(dpr);
+      finalPm = expandPixmap(pm, btnSz, bgColor);
+      finalPm.setDevicePixelRatio(dpr);
+
+      addToPixmapCache(cacheKey, finalPm);
+    } else
+      return;
+  }
+
+  p.setRenderHint(QPainter::SmoothPixmapTransform);
+  p.drawPixmap(0, 0, finalPm);
 }
 
 //-----------------------------------------------------------------------------
@@ -408,6 +492,58 @@ void TPanelTitleBarButtonForSafeArea::onSetSafeArea() {
 
 //-----------------------------------------------------------------------------
 
+//=============================================================================
+// TPanelTitleBarButtonForPreview
+//-----------------------------------------------------------------------------
+
+void TPanelTitleBarButtonForPreview::mousePressEvent(QMouseEvent *e) {
+  if (e->button() != Qt::RightButton) {
+    m_pressed = !m_pressed;
+    emit toggled(m_pressed);
+    update();
+  }
+}
+
+//-----------------------------------------------------------------------------
+
+void TPanelTitleBarButtonForPreview::contextMenuEvent(QContextMenuEvent *e) {
+  QMenu menu(this);
+
+  // 0: current frame
+  // 1: all frames in the preview range
+  // 2: selected cell, auto play once & stop
+  QStringList behaviorsStrList = {tr("Current frame"),
+                                  tr("All preview range frames"),
+                                  tr("Selected cells - Auto play")};
+
+  QActionGroup *behaviorGroup = new QActionGroup(this);
+
+  for (int i = 0; i < behaviorsStrList.size(); i++) {
+    QAction *action = menu.addAction(behaviorsStrList.at(i));
+    action->setData(i);
+    connect(action, SIGNAL(triggered()), this, SLOT(onSetPreviewBehavior()));
+    action->setCheckable(true);
+    behaviorGroup->addAction(action);
+    if (i == EnvViewerPreviewBehavior) action->setChecked(true);
+  }
+
+  menu.exec(e->globalPos());
+}
+
+//-----------------------------------------------------------------------------
+
+void TPanelTitleBarButtonForPreview::onSetPreviewBehavior() {
+  int behaviorId = qobject_cast<QAction *>(sender())->data().toInt();
+  // change safearea if the different one is selected
+  if (EnvViewerPreviewBehavior != behaviorId) {
+    EnvViewerPreviewBehavior = behaviorId;
+    // emit sceneChanged without setting dirty flag
+    TApp::instance()->getCurrentScene()->notifySceneChanged(false);
+  }
+}
+
+//-----------------------------------------------------------------------------
+
 //=============================================================================
 // TPanelTitleBarButtonSet
 //-----------------------------------------------------------------------------
@@ -449,21 +585,13 @@ void TPanelTitleBar::paintEvent(QPaintEvent *) {
   QRect rect = this->rect();
 
   bool isPanelActive;
-
   TPanel *dw = qobject_cast<TPanel *>(parentWidget());
   Q_ASSERT(dw != 0);
-  // docked panel
-  if (!dw->isFloating()) {
+
+  if (!dw->isFloating()) {  // docked panel
     isPanelActive = dw->widgetInThisPanelIsFocused();
-    qDrawBorderPixmap(&painter, rect, QMargins(3, 3, 3, 3),
-                      (isPanelActive) ? m_activeBorderPm : m_borderPm);
-  }
-  // floating panel
-  else {
+  } else {  // floating panel
     isPanelActive = isActiveWindow();
-    qDrawBorderPixmap(
-        &painter, rect, QMargins(3, 3, 3, 3),
-        (isPanelActive) ? m_floatActiveBorderPm : m_floatBorderPm);
   }
 
   if (dw->getOrientation() == TDockWidget::vertical) {
@@ -476,21 +604,64 @@ void TPanelTitleBar::paintEvent(QPaintEvent *) {
   }
 
   if (dw->isFloating()) {
-    QIcon paneCloseIcon = createQIcon("pane_close");
-    const static QPixmap closeButtonPixmap(
-        paneCloseIcon.pixmap(20, 18, QIcon::Normal, QIcon::Off));
-    const static QPixmap closeButtonPixmapOver(
-        paneCloseIcon.pixmap(20, 18, QIcon::Active));
+    QPoint btnPos(rect.right() - 19, rect.top());
+    qreal dpr    = getDevicePixelRatio(this);
+    QSize btnSz  = minimumSizeHint() * dpr;
+    QSize iconSz = QSize(16, 16);
 
-    QPoint closeButtonPos(rect.right() - 20, rect.top());
+    // Icon mode and background color
+    bool highlighted = m_closeButtonHighlighted;
+    QIcon::Mode mode = highlighted ? QIcon::Active : QIcon::Normal;
+    QColor bgColor   = highlighted ? getCloseOverColor() : Qt::transparent;
 
-    if (m_closeButtonHighlighted)
-      painter.drawPixmap(closeButtonPos, closeButtonPixmapOver);
-    else
-      painter.drawPixmap(closeButtonPos, closeButtonPixmap);
+    // Cache key
+    QString cacheKey =
+        generateCacheKey("closewindow", btnSz, mode, QIcon::Off) +
+        QString::number(dpr);
+
+    // Check cache first
+    QPixmap finalPm = getFromPixmapCache(cacheKey);
+    if (!finalPm.isNull()) {
+      painter.drawPixmap(btnPos, finalPm);
+      return;
+    }
+
+    // Load icon at logical size
+    QPixmap pm = SvgIconEngine("closewindow", false, dpr, iconSz)
+                     .pixmap(iconSz, mode, QIcon::Off);
+    if (pm.isNull()) return;
+
+    pm.setDevicePixelRatio(dpr);
+    finalPm = expandPixmap(pm, btnSz, bgColor);
+    finalPm.setDevicePixelRatio(dpr);
+
+    // Cache and draw
+    addToPixmapCache(cacheKey, finalPm);
+    painter.drawPixmap(btnPos, finalPm);
   }
+}
 
-  painter.end();
+//-----------------------------------------------------------------------------
+
+void TPanelTitleBar::setCloseOverColor(const QColor &color) {
+  if (m_closeOverColor != color) {
+    m_closeOverColor = color;
+  }
+}
+
+QColor TPanelTitleBar::getCloseOverColor() const { return m_closeOverColor; }
+
+//-----------------------------------------------------------------------------
+
+void TPanelTitleBar::leaveEvent(QEvent *) {
+  TPanel *dw = qobject_cast<TPanel *>(parentWidget());
+  Q_ASSERT(dw != 0);
+
+  // Mouse left the widget, reset the highlighted flag
+  if (dw->isFloating()) {
+    m_closeButtonHighlighted = false;
+    update();
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -587,6 +758,12 @@ TPanel *TPanelFactory::createPanel(QWidget *parent, QString panelType) {
 
   QMap<QString, TPanelFactory *>::iterator it = tableInstance().find(panelType);
   if (it == tableInstance().end()) {
+    if (panelType.startsWith("Custom_")) {
+      panelType = panelType.right(panelType.size() - 7);
+      return CustomPanelManager::instance()->createCustomPanel(panelType,
+                                                               parent);
+    }
+
     TPanel *panel = new TPanel(parent);
     panel->setPanelType(panelType.toStdString());
     return panel;
