@@ -713,7 +713,7 @@ void PreviewFxInstance::updateRenderSettings() {
 
   m_subcamera = properties->isSubcameraPreview();
 
-  const TRenderSettings &renderSettings = properties->getRenderSettings();
+  TRenderSettings renderSettings = properties->getRenderSettings();
 
   if (m_renderSettings != renderSettings) {
     m_renderSettings = renderSettings;
@@ -1067,9 +1067,17 @@ void PreviewFxInstance::doOnRenderRasterCompleted(
   else
     ras = 0;
 
-  /*-- 16bpcで計算された場合、結果をDitheringする --*/
   TRasterP rasA = renderData.m_rasA;
   TRasterP rasB = renderData.m_rasB;
+
+  // Linear Color Space -> sRGB
+  if (rasA->isLinear()) {
+    TRop::tosRGB(rasA, m_renderSettings.m_colorSpaceGamma);
+    if (m_renderSettings.m_stereoscopic)
+      TRop::tosRGB(rasB, m_renderSettings.m_colorSpaceGamma);
+  }
+
+  /*-- 16bpcで計算された場合、結果をDitheringする --*/
   // dither the 16bpc image IF the "30bit display" preference option is OFF
   if (rasA->getPixelSize() == 8 &&
       !Preferences::instance()->is30bitDisplayEnabled())  // render in 64 bits
@@ -1456,6 +1464,7 @@ void PreviewFxManager::onLevelChanged() {
     // Build the level name as an alias keyword. All cache images associated
     // with an alias containing the level name will be updated.
     TXshLevel *xl = TApp::instance()->getCurrentLevel()->getLevel();
+    if (!xl) return;
     std::string aliasKeyword;
     TFilePath fp = xl->getPath();
     aliasKeyword = ::to_string(fp.withType(""));
