@@ -73,7 +73,7 @@ public:
 //-----------------------------------------------------------------------------
 
 ShortcutViewer::ShortcutViewer(QWidget *parent)
-    : QKeySequenceEdit(parent), m_action(0) {
+    : QKeySequenceEdit(parent), m_action(0), m_keysPressed(0) {
   setObjectName("ShortcutViewer");
   setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
   connect(this, SIGNAL(editingFinished()), this, SLOT(onEditingFinished()));
@@ -102,53 +102,126 @@ void ShortcutViewer::setAction(QAction *action) {
 void ShortcutViewer::keyPressEvent(QKeyEvent *event) {
   int key                         = event->key();
   Qt::KeyboardModifiers modifiers = event->modifiers();
-  if (key == Qt::Key_Home || key == Qt::Key_End || key == Qt::Key_PageDown ||
-      key == Qt::Key_PageUp || key == Qt::Key_Escape || key == Qt::Key_Print ||
-      key == Qt::Key_Pause || key == Qt::Key_ScrollLock) {
-    event->ignore();
-    return;
-  }
-  // If "Use Numpad and Tab keys for Switching Styles" option is activated,
-  // then prevent to assign such keys
-  if (Preferences::instance()->isUseNumpadForSwitchingStylesEnabled() &&
-      modifiers == 0 && (key >= Qt::Key_0 && key <= Qt::Key_9)) {
-    event->ignore();
-    return;
+
+  if (m_keysPressed == 0) {
+    if (key == Qt::Key_Home || key == Qt::Key_End || key == Qt::Key_PageDown ||
+        key == Qt::Key_PageUp || key == Qt::Key_Escape ||
+        key == Qt::Key_Print || key == Qt::Key_Pause ||
+        key == Qt::Key_ScrollLock) {
+      event->ignore();
+      return;
+    }
+
+    // If "Use Numpad and Tab keys for Switching Styles" option is activated,
+    // then prevent to assign such keys
+    if (Preferences::instance()->isUseNumpadForSwitchingStylesEnabled() &&
+        modifiers == 0 && (key >= Qt::Key_0 && key <= Qt::Key_9)) {
+      event->ignore();
+      return;
+    }
   }
+
+  m_keysPressed++;
+
   QKeySequenceEdit::keyPressEvent(event);
 }
 
 //-----------------------------------------------------------------------------
 
 void ShortcutViewer::onEditingFinished() {
-  // limit to one shortcut key input
-  QKeySequence keys = (keySequence().isEmpty())
-                          ? QKeySequence()
-                          : QKeySequence(keySequence()[0]);
+  // Get the current key sequence and its string representation
+  QKeySequence keySeq = keySequence();
+  QString keyStr      = keySeq.toString();
 
+  // Check for reserved key combinations involving the Space key
+  if (keyStr.contains("Space", Qt::CaseInsensitive)) {
+    // Check for Space + Shift combination
+    if (keyStr.contains("Shift", Qt::CaseInsensitive)) {
+      setKeySequence(m_action->shortcut());  // Reset to the original shortcut
+      DVGui::warning(
+          tr("The Space + Shift combination is reserved for viewer rotation."));
+      return;
+    }
+
+    // Check for Space + Ctrl combination
+    if (keyStr.contains("Ctrl", Qt::CaseInsensitive)) {
+      setKeySequence(m_action->shortcut());  // Reset to the original shortcut
+      DVGui::warning(
+          tr("The Space + Ctrl combination is reserved for viewer zoom."));
+      return;
+    }
+
+    // Check for Space key alone
+    setKeySequence(m_action->shortcut());  // Reset to the original shortcut
+    DVGui::warning(tr("The Space key is reserved for viewer navigation."));
+    return;
+  }
+
+  // Reset the keys pressed counter (used for tracking multi-key sequences)
+  m_keysPressed = 0;
+
+  // Extract individual keys from the key sequence
+  QVector<int> keys;
+  for (int i = 0; i < keySeq.count(); i++) {
+    keys.append(keySeq[i]);
+  }
+
+  // Check for conflicts with existing shortcuts
   if (m_action) {
-    CommandManager *cm         = CommandManager::instance();
-    std::string shortcutString = keys.toString().toStdString();
-    QAction *oldAction =
-        cm->getActionFromShortcut(keys.toString().toStdString());
-    if (oldAction == m_action) return;
-    if (oldAction) {
-      QString msg = tr("%1 is already assigned to '%2'\nAssign to '%3'?")
-                        .arg(keys.toString())
-                        .arg(oldAction->iconText())
-                        .arg(m_action->iconText());
-      int ret = DVGui::MsgBox(msg, tr("Yes"), tr("No"), 1);
-      activateWindow();
-      if (ret == 2 || ret == 0) {
-        setKeySequence(m_action->shortcut());
-        setFocus();
-        return;
+    CommandManager *cm = CommandManager::instance();
+
+    // Iterate through the key sequence to check for partial conflicts
+    for (int i = 0; i < keys.size(); i++) {
+      // Create a partial key sequence (e.g., k1, k1+k2, k1+k2+k3, etc.)
+      QKeySequence partialSeq(keys[0], (i >= 1 ? keys[1] : 0),
+                              (i >= 2 ? keys[2] : 0), (i >= 3 ? keys[3] : 0));
+
+      // Check if the partial sequence conflicts with an existing shortcut
+      QAction *conflictingAction =
+          cm->getActionFromShortcut(partialSeq.toString().toStdString());
+
+      if (conflictingAction == m_action) return;
+
+      // If a conflict is found with another action
+      if (conflictingAction) {
+        QString msg;
+        // Check if the conflict is with the full sequence or a partial sequence
+        if (keys.size() == (i + 1)) {
+          // Conflict with the full sequence
+          msg = tr("'%1' is already assigned to '%2'\nAssign to '%3'?")
+                    .arg(partialSeq.toString())
+                    .arg(conflictingAction->iconText())
+                    .arg(m_action->iconText());
+        } else {
+          // Conflict with a partial sequence
+          msg = tr("Initial sequence '%1' is assigned to '%2' which takes "
+                   "priority.\nAssign shortcut sequence anyway?")
+                    .arg(partialSeq.toString())
+                    .arg(conflictingAction->iconText());
+        }
+
+        // Show a warning message box to the user
+        int ret = DVGui::MsgBox(msg, tr("Yes"), tr("No"), 1);
+        activateWindow();
+
+        // If the user chooses "No" or closes the dialog, reset the shortcut and
+        // exit
+        if (ret != 1) {  // 1 corresponds to "Yes"
+          setKeySequence(
+              m_action->shortcut());  // Reset to the original shortcut
+          setFocus();                 // Set focus back to the widget
+          return;
+        }
       }
     }
-    CommandManager::instance()->setShortcut(m_action, shortcutString);
+
+    // If no conflicts are found, assign the new shortcut
+    std::string shortcutString = keySeq.toString().toStdString();
+    cm->setShortcut(m_action, shortcutString);
     emit shortcutChanged();
   }
-  setKeySequence(keys);
+
+  setKeySequence(keySeq);  // Update the displayed key sequence in the UI
 }
 
 //-----------------------------------------------------------------------------
@@ -183,6 +256,9 @@ ShortcutTree::ShortcutTree(QWidget *parent) : QTreeWidget(parent) {
 
   setColumnCount(2);
   header()->close();
+  header()->setSectionResizeMode(0, QHeaderView::ResizeMode::Fixed);
+  header()->setSectionResizeMode(1, QHeaderView::ResizeMode::ResizeToContents);
+  header()->setDefaultSectionSize(300);
   // setStyleSheet("border-bottom:1px solid rgb(120,120,120); border-left:1px
   // solid rgb(120,120,120); border-top:1px solid rgb(120,120,120)");
 
@@ -318,14 +394,6 @@ void ShortcutTree::searchItems(const QString &searchWord) {
 
 //-----------------------------------------------------------------------------
 
-void ShortcutTree::resizeEvent(QResizeEvent *event) {
-  header()->resizeSection(0, width() - 120);
-  header()->resizeSection(1, 120);
-  QTreeView::resizeEvent(event);
-}
-
-//-----------------------------------------------------------------------------
-
 void ShortcutTree::onCurrentItemChanged(QTreeWidgetItem *current,
                                         QTreeWidgetItem *previous) {
   ShortcutItem *item = dynamic_cast<ShortcutItem *>(current);
