@@ -42,6 +42,7 @@
 #include "toonz/tfxhandle.h"
 #include "toonz/scenefx.h"
 #include "toonz/preferences.h"
+#include "toonz/navigationtags.h"
 
 // TnzQt includes
 #include "toonzqt/tselectionhandle.h"
@@ -49,6 +50,7 @@
 #include "toonzqt/menubarcommand.h"
 #include "toonzqt/stageobjectsdata.h"
 #include "historytypes.h"
+#include "xsheetviewer.h"
 
 // Tnz6 includes
 #include "cellselection.h"
@@ -60,6 +62,7 @@
 #include "menubarcommandids.h"
 #include "columncommand.h"
 #include "xshcellviewer.h"  // SetCellMarkUndo
+#include "navtageditorpopup.h"
 
 // Qt includes
 #include <QClipboard>
@@ -68,8 +71,6 @@
 #include "tcg/boost/range_utility.h"
 
 // boost includes
-#include <boost/bind.hpp>
-#include <boost/bind/make_adaptable.hpp>
 #include <boost/range/adaptor/filtered.hpp>
 #include <boost/range/adaptor/transformed.hpp>
 
@@ -176,6 +177,8 @@ void InsertSceneFrameUndo::doInsertSceneFrame(int frame) {
     if (TStageObject *obj = xsh->getStageObject(objectId))
       insertFrame(obj, frame);
   }
+
+  xsh->getNavigationTags()->shiftTags(frame, 1);
 }
 
 //-----------------------------------------------------------------------------
@@ -199,6 +202,9 @@ void InsertSceneFrameUndo::doRemoveSceneFrame(int frame) {
     if (TStageObject *pegbar = xsh->getStageObject(objectId))
       removeFrame(pegbar, frame);
   }
+
+  if (xsh->isFrameTagged(frame)) xsh->getNavigationTags()->removeTag(frame);
+  xsh->getNavigationTags()->shiftTags(frame, -1);
 }
 
 //-----------------------------------------------------------------------------
@@ -242,6 +248,7 @@ public:
 class RemoveSceneFrameUndo final : public InsertSceneFrameUndo {
   std::vector<TXshCell> m_cells;
   std::vector<TStageObject::Keyframe> m_keyframes;
+  NavigationTags::Tag m_tag;
 
 public:
   RemoveSceneFrameUndo(int frame) : InsertSceneFrameUndo(frame) {
@@ -252,6 +259,7 @@ public:
 
     m_cells.resize(colsCount);
     m_keyframes.resize(colsCount + 1);
+    m_tag = xsh->getNavigationTags()->getTag(frame);
 
     // Inserting the eventual camera keyframe at the end
     TStageObject *cameraObj = xsh->getStageObject(
@@ -296,6 +304,10 @@ public:
       }
     }
 
+    // Restore tag if there was one
+    if (m_tag.m_frame != -1)
+      xsh->getNavigationTags()->addTag(m_tag.m_frame, m_tag.m_label);
+
     TApp::instance()->getCurrentScene()->setDirtyFlag(true);
     TApp::instance()->getCurrentXsheet()->notifyXsheetChanged();
   }
@@ -417,8 +429,7 @@ public:
       : GlobalKeyframeUndo(frame) {
     tcg::substitute(
         m_columns,
-        columns | ba::filtered(std::not1(boost::make_adaptable<bool, int>(
-                      boost::bind(isKeyframe, frame, _1)))));
+        columns | ba::filtered([frame](int c){ return !isKeyframe(frame, c); }));
   }
 
   void redo() const override {
@@ -492,11 +503,10 @@ public:
     };  // locals
 
     tcg::substitute(m_columns,
-                    columns | ba::filtered(boost::bind(isKeyframe, frame, _1)));
+                    columns | ba::filtered([frame](int c){ return isKeyframe(frame, c); }));
 
     tcg::substitute(m_keyframes,
-                    m_columns | ba::transformed(boost::bind(locals::getKeyframe,
-                                                            frame, _1)));
+                    m_columns | ba::transformed([frame](int c){ return locals::getKeyframe(frame, c); }));
   }
 
   void redo() const override {
@@ -2183,4 +2193,106 @@ SetCellMarkCommand CellMarkCommand7(7);
 SetCellMarkCommand CellMarkCommand8(8);
 SetCellMarkCommand CellMarkCommand9(9);
 SetCellMarkCommand CellMarkCommand10(10);
-SetCellMarkCommand CellMarkCommand11(11);
\ No newline at end of file
+SetCellMarkCommand CellMarkCommand11(11);
+
+//============================================================
+
+class ToggleTaggedFrame final : public MenuItemHandler {
+public:
+  ToggleTaggedFrame() : MenuItemHandler(MI_ToggleTaggedFrame) {}
+  void execute() override {
+    TApp *app = TApp::instance();
+    int frame = app->getCurrentFrame()->getFrame();
+    assert(frame >= 0);
+    TXsheet *xsh = app->getCurrentXsheet()->getXsheet();
+
+    xsh->toggleTaggedFrame(frame);
+
+    NavigationTags *navTags = xsh->getNavigationTags();
+    CommandManager::instance()->enable(MI_EditTaggedFrame,
+                                       navTags->isTagged(frame));
+    CommandManager::instance()->enable(MI_ClearTags, (navTags->getCount() > 0));
+
+    TApp::instance()->getCurrentXsheetViewer()->update();
+  }
+} ToggleTaggedFrame;
+
+//============================================================
+
+class EditTaggedFrame final : public MenuItemHandler {
+public:
+  EditTaggedFrame() : MenuItemHandler(MI_EditTaggedFrame) {}
+  void execute() override {
+    TApp *app = TApp::instance();
+    int frame = app->getCurrentFrame()->getFrame();
+    assert(frame >= 0);
+    TXsheet *xsh = app->getCurrentXsheet()->getXsheet();
+
+    NavigationTags *tags = xsh->getNavigationTags();
+    QString label        = tags->getTagLabel(frame);
+    QColor color         = tags->getTagColor(frame);
+    NavTagEditorPopup navTagEditor(frame, label, color);
+    if (navTagEditor.exec() != QDialog::Accepted) return;
+    tags->setTagLabel(frame, navTagEditor.getLabel());
+    tags->setTagColor(frame, navTagEditor.getColor());
+  }
+} EditTaggedFrame;
+
+//============================================================
+
+class NextTaggedFrame final : public MenuItemHandler {
+public:
+  NextTaggedFrame() : MenuItemHandler(MI_NextTaggedFrame) {}
+  void execute() override {
+    TApp *app = TApp::instance();
+    int frame = app->getCurrentFrame()->getFrame();
+    assert(frame >= 0);
+    TXsheet *xsh = app->getCurrentXsheet()->getXsheet();
+
+    NavigationTags *navTags = xsh->getNavigationTags();
+    int nextFrame           = navTags->getNextTag(frame);
+    if (nextFrame != -1)
+      app->getCurrentXsheetViewer()->setCurrentRow(nextFrame);
+  }
+} NextTaggedFrame;
+
+//============================================================
+
+class PrevTaggedFrame final : public MenuItemHandler {
+public:
+  PrevTaggedFrame() : MenuItemHandler(MI_PrevTaggedFrame) {}
+  void execute() override {
+    TApp *app = TApp::instance();
+    int frame = app->getCurrentFrame()->getFrame();
+    assert(frame >= 0);
+    TXsheet *xsh = app->getCurrentXsheet()->getXsheet();
+
+    NavigationTags *navTags = xsh->getNavigationTags();
+    int prevFrame           = navTags->getPrevTag(frame);
+    if (prevFrame != -1)
+      app->getCurrentXsheetViewer()->setCurrentRow(prevFrame);
+  }
+} PrevTaggedFrame;
+
+//============================================================
+
+class ClearTags final : public MenuItemHandler {
+public:
+  ClearTags() : MenuItemHandler(MI_ClearTags) {}
+  void execute() override {
+    TApp *app = TApp::instance();
+    int frame = app->getCurrentFrame()->getFrame();
+    assert(frame >= 0);
+    TXsheet *xsh = app->getCurrentXsheet()->getXsheet();
+
+    NavigationTags *navTags = xsh->getNavigationTags();
+    navTags->clearTags();
+
+    CommandManager::instance()->enable(MI_NextTaggedFrame, false);
+    CommandManager::instance()->enable(MI_PrevTaggedFrame, false);
+    CommandManager::instance()->enable(MI_EditTaggedFrame, false);
+    CommandManager::instance()->enable(MI_ClearTags, false);
+
+    TApp::instance()->getCurrentXsheetViewer()->update();
+  }
+} ClearTags;
