@@ -28,6 +28,7 @@
 #include "tools/toolcommandids.h"
 #include "toonz/tstageobject.h"
 #include "toonz/tpinnedrangeset.h"
+#include "toonz/navigationtags.h"
 
 #include <QPainter>
 #include <QMouseEvent>
@@ -42,11 +43,7 @@ namespace XsheetGUI {
 // RowArea
 //-----------------------------------------------------------------------------
 
-#if QT_VERSION >= 0x050500
 RowArea::RowArea(XsheetViewer *parent, Qt::WindowFlags flags)
-#else
-RowArea::RowArea(XsheetViewer *parent, Qt::WFlags flags)
-#endif
     : QWidget(parent, flags)
     , m_viewer(parent)
     , m_row(-1)
@@ -78,6 +75,14 @@ void RowArea::setDragTool(DragTool *dragTool) {
   m_viewer->setDragTool(dragTool);
 }
 
+//-----------------------------------------------------------------------------
+// returns true if the frame area can have extra space
+bool RowArea::checkExpandFrameArea() {
+  return m_viewer->orientation()->isVerticalTimeline() &&
+         !Preferences::instance()->isOnionSkinEnabled() &&
+         !CommandManager::instance()->getAction(MI_ShiftTrace)->isChecked();
+}
+
 //-----------------------------------------------------------------------------
 
 void RowArea::drawRows(QPainter &p, int r0, int r1) {
@@ -106,9 +111,9 @@ void RowArea::drawRows(QPainter &p, int r0, int r1) {
   p.setFont(font);
 
   // marker interval
-  int distance, offset;
+  int distance, offset, secDistance;
   TApp::instance()->getCurrentScene()->getScene()->getProperties()->getMarkers(
-      distance, offset);
+      distance, offset, secDistance);
 
   // default value
   //  if (distance == 0) distance = 6;
@@ -125,15 +130,28 @@ void RowArea::drawRows(QPainter &p, int r0, int r1) {
   bool simpleView = m_viewer->getFrameZoomFactor() <=
                     o->dimension(PredefinedDimension::SCALE_THRESHOLD);
 
+  int currentRow = m_viewer->getCurrentRow();
+  bool hasCurrentFrameTextColor =
+      m_viewer->getTextColor() != m_viewer->getCurrentFrameTextColor();
+
   for (int r = r0; r <= r1; r++) {
     int frameAxis = m_viewer->rowToFrameAxis(r);
 
     //--- draw horizontal line
     bool isAfterMarkers =
         (distance > 0 && ((r - offset) % distance) == 0 && r != 0);
-    QColor color = isAfterMarkers ? m_viewer->getMarkerLineColor()
-                                  : m_viewer->getLightLineColor();
-    p.setPen(color);
+    bool isAfterSecMarkers =
+        secDistance > 0 && ((r - offset) % secDistance) == 0 && r != 0;
+
+    QColor color     = (isAfterSecMarkers) ? m_viewer->getSecMarkerLineColor()
+                       : (isAfterMarkers)  ? m_viewer->getMarkerLineColor()
+                                           : m_viewer->getLightLineColor();
+    double lineWidth = (isAfterSecMarkers)                   ? 3.
+                       : (secDistance > 0 && isAfterMarkers) ? 2.
+                                                             : 1.;
+
+    p.setPen(QPen(color, lineWidth, Qt::SolidLine, Qt::FlatCap));
+    // p.setPen(color);
     QLine horizontalLine = o->horizontalLine(frameAxis, layerSide);
     if (!o->isVerticalTimeline()) {
       int x = horizontalLine.x1();
@@ -144,16 +162,26 @@ void RowArea::drawRows(QPainter &p, int r0, int r1) {
     p.drawLine(horizontalLine);
   }
 
+  int extraSpaces = 0;
+  if (checkExpandFrameArea()) {
+    extraSpaces =
+        std::max(0, o->rect(PredefinedRect::FRAME_LABEL).width() /
+                            QFontMetrics(p.font()).boundingRect("0").width() -
+                        6);
+  }
+
   int z = 0;
   for (int r = r0; r <= r1; r++) {
     // draw frame text
-    if (playR0 <= r && r <= playR1) {
+    if (hasCurrentFrameTextColor && r == currentRow)
+      p.setPen(m_viewer->getCurrentFrameTextColor());
+    else if (playR0 <= r && r <= playR1) {
       p.setPen(((r - m_r0) % step == 0) ? m_viewer->getPreviewFrameTextColor()
                                         : m_viewer->getTextColor());
     }
     // not in preview range
     else
-      p.setPen(m_viewer->getTextColor());
+      p.setPen(m_viewer->getFrameTextColor());
 
     QPoint basePoint = m_viewer->positionToXY(CellPosition(r, -1));
     if (!o->isVerticalTimeline())
@@ -220,8 +248,9 @@ void RowArea::drawRows(QPainter &p, int r0, int r1) {
       int koma = (r + 1) % (frameRate * 6);
       if ((r + 1) % frameRate == 1) {
         int page = (r + 1) / (frameRate * 6) + 1;
-        str      = QString("p%1 %2")
+        str      = QString("p%1%2%3")
                   .arg(QString::number(page))
+                  .arg(QString().leftJustified(1 + extraSpaces, ' '))
                   .arg(QString::number(koma).rightJustified(3, '0'));
         z = 0;
       } else {
@@ -249,8 +278,9 @@ void RowArea::drawRows(QPainter &p, int r0, int r1) {
       int koma = (r + 1) % (frameRate * 3);
       if ((r + 1) % frameRate == 1) {
         int page = (r + 1) / (frameRate * 3) + 1;
-        str      = QString("p%1 %2")
+        str      = QString("p%1%2%3")
                   .arg(QString::number(page))
+                  .arg(QString().leftJustified(2 + extraSpaces, ' '))
                   .arg(QString::number(koma).rightJustified(2, '0'));
         z = 0;
       } else {
@@ -279,6 +309,12 @@ void RowArea::drawPlayRangeBackground(QPainter &p, int r0, int r1) {
   int playR0, playR1, step;
   XsheetGUI::getPlayRange(playR0, playR1, step);
 
+  int hExpansion = 0;
+  if (checkExpandFrameArea()) {
+    hExpansion = m_viewer->orientation()->dimension(
+        PredefinedDimension::FRAME_AREA_EXPANSION);
+  }
+
   for (int r = r0; r <= r1; r++) {
     if (!(playR0 <= r && r <= playR1) && ((r - m_r0) % step == 0)) continue;
 
@@ -288,9 +324,10 @@ void RowArea::drawPlayRangeBackground(QPainter &p, int r0, int r1) {
     else
       basePoint.setX(0);
 
-    QRect previewBoxRect = o->rect(PredefinedRect::PREVIEW_FRAME_AREA)
-                               .adjusted(0, 0, -frameAdj.x(), -frameAdj.y())
-                               .translated(basePoint);
+    QRect previewBoxRect =
+        o->rect(PredefinedRect::PREVIEW_FRAME_AREA)
+            .adjusted(-hExpansion, 0, -frameAdj.x(), -frameAdj.y())
+            .translated(basePoint);
     p.fillRect(previewBoxRect, m_viewer->getPlayRangeColor());
 
     if (!o->isVerticalTimeline()) {
@@ -327,6 +364,12 @@ void RowArea::drawPlayRange(QPainter &p, int r0, int r1) {
     m_r0 = 0;
   }
 
+  int hOffset = 0;
+  if (checkExpandFrameArea()) {
+    hOffset = m_viewer->orientation()->dimension(
+        PredefinedDimension::FRAME_AREA_EXPANSION);
+  }
+
   QColor ArrowColor = (playRangeEnabled) ? QColor(255, 255, 255) : grey150;
   p.setBrush(QBrush(ArrowColor));
 
@@ -335,7 +378,7 @@ void RowArea::drawPlayRange(QPainter &p, int r0, int r1) {
     if (!m_viewer->orientation()->isVerticalTimeline())
       topLeft.setY(0);
     else
-      topLeft.setX(0);
+      topLeft.setX(-hOffset);
     m_viewer->drawPredefinedPath(p, PredefinedPath::BEGIN_PLAY_RANGE, topLeft,
                                  ArrowColor, QColor(Qt::black));
   }
@@ -346,7 +389,7 @@ void RowArea::drawPlayRange(QPainter &p, int r0, int r1) {
     if (!m_viewer->orientation()->isVerticalTimeline())
       topLeft.setY(0);
     else
-      topLeft.setX(0);
+      topLeft.setX(-hOffset);
     m_viewer->drawPredefinedPath(p, PredefinedPath::END_PLAY_RANGE, topLeft,
                                  ArrowColor, QColor(Qt::black));
   }
@@ -366,6 +409,7 @@ void RowArea::drawCurrentRowGadget(QPainter &p, int r0, int r1) {
   QRect header = m_viewer->orientation()
                      ->rect(PredefinedRect::FRAME_HEADER)
                      .translated(topLeft);
+
   QPoint frameAdj = m_viewer->getFrameZoomAdjustment();
   header.adjust(1, 1, -frameAdj.x(), -frameAdj.y());
   p.fillRect(header, m_viewer->getCurrentRowBgColor());
@@ -391,6 +435,50 @@ void RowArea::drawStopMotionCameraIndicator(QPainter &p) {
 //-----------------------------------------------------------------------------
 #endif
 
+void RowArea::drawNavigationTags(QPainter &p, int r0, int r1) {
+  TApp *app    = TApp::instance();
+  TXsheet *xsh = app->getCurrentScene()->getScene()->getXsheet();
+  assert(xsh);
+
+  QPoint frameAdj = m_viewer->getFrameZoomAdjustment();
+
+  NavigationTags *tags = xsh->getNavigationTags();
+
+  for (int r = r0; r <= r1; r++) {
+    if (!xsh->isFrameTagged(r)) continue;
+
+    QPoint topLeft = m_viewer->positionToXY(CellPosition(r, -1));
+    if (!m_viewer->orientation()->isVerticalTimeline())
+      topLeft.setY(0);
+    else
+      topLeft.setX(0);
+
+    QRect tagRect = m_viewer->orientation()
+                        ->rect(PredefinedRect::NAVIGATION_TAG_AREA)
+                        .translated(topLeft)
+                        .translated(-frameAdj / 2);
+
+    int frameMid, frameTop;
+    if (m_viewer->orientation()->isVerticalTimeline()) {
+      frameMid = tagRect.left() - 3;
+      frameTop = tagRect.top() + (tagRect.height() / 2);
+    } else {
+      frameMid = tagRect.left() + (tagRect.height() / 2) - 3;
+      frameTop = tagRect.top() + 1;
+    }
+
+    QPainterPath tag = m_viewer->orientation()
+                           ->path(PredefinedPath::NAVIGATION_TAG)
+                           .translated(QPoint(frameMid, frameTop));
+    p.setPen(Qt::black);
+    p.setBrush(tags->getTagColor(r));
+    p.drawPath(tag);
+    p.setBrush(Qt::NoBrush);
+  }
+}
+
+//-----------------------------------------------------------------------------
+
 void RowArea::drawOnionSkinBackground(QPainter &p, int r0, int r1) {
   const Orientation *o = m_viewer->orientation();
 
@@ -640,8 +728,9 @@ void RowArea::drawCurrentTimeIndicator(QPainter &p) {
 }
 
 void RowArea::drawCurrentTimeLine(QPainter &p) {
-  QPoint frameAdj = m_viewer->getFrameZoomAdjustment();
-  int currentRow  = m_viewer->getCurrentRow();
+  QPoint frameAdj       = m_viewer->getFrameZoomAdjustment();
+  int currentRow        = m_viewer->getCurrentRow();
+  QColor indicatorColor = m_viewer->getCurrentTimeIndicatorColor();
 
   QPoint topLeft = m_viewer->positionToXY(CellPosition(currentRow, -1));
   if (!m_viewer->orientation()->isVerticalTimeline())
@@ -650,15 +739,22 @@ void RowArea::drawCurrentTimeLine(QPainter &p) {
     topLeft.setX(0);
   QRect header = m_viewer->orientation()
                      ->rect(PredefinedRect::FRAME_HEADER)
-                     .translated(topLeft)
-                     .translated(-frameAdj / 2);
+                     .translated(topLeft);
 
-  int frameMid    = header.left() + (header.width() / 2) - 1;
-  int frameTop    = header.top();
-  int frameBottom = header.bottom();
+  if (m_viewer->orientation()->isVerticalTimeline()) {
+    header.adjust(1, 1, -frameAdj.x(), -frameAdj.y());
+    p.setPen(
+        QPen(indicatorColor, 1, Qt::SolidLine, Qt::SquareCap, Qt::MiterJoin));
+    p.drawRect(header.adjusted(0, 0, -1, -1));
+  } else {
+    header.translate(-frameAdj / 2);
+    int frameMid    = header.left() + (header.width() / 2) - 1;
+    int frameTop    = header.top();
+    int frameBottom = header.bottom();
 
-  p.setPen(Qt::red);
-  p.drawLine(frameMid, frameTop + 23, frameMid, frameBottom);
+    p.setPen(indicatorColor);
+    p.drawLine(frameMid, frameTop + 23, frameMid, frameBottom);
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -673,8 +769,8 @@ void RowArea::drawShiftTraceMarker(QPainter &p) {
 
   QPoint frameAdj = m_viewer->getFrameZoomAdjustment();
   int frameAdj_i  = (m_viewer->orientation()->isVerticalTimeline())
-                       ? frameAdj.y()
-                       : frameAdj.x();
+                        ? frameAdj.y()
+                        : frameAdj.x();
 
   // get onion colors
   TPixel frontPixel, backPixel;
@@ -887,11 +983,14 @@ void RowArea::paintEvent(QPaintEvent *event) {
   }
 #endif
 
+  // For now, the current frame indicator is not displayed in the xsheet row
+  // area
   if (TApp::instance()->getCurrentFrame()->isEditingScene() &&
-      Preferences::instance()->isCurrentTimelineIndicatorEnabled() &&
-      !m_viewer->orientation()->isVerticalTimeline())
+      Preferences::instance()->isCurrentTimelineIndicatorEnabled())
     drawCurrentTimeLine(p);
 
+  drawNavigationTags(p, r0, r1);
+
   drawRows(p, r0, r1);
 
   if (TApp::instance()->getCurrentFrame()->isEditingScene()) {
@@ -899,6 +998,8 @@ void RowArea::paintEvent(QPaintEvent *event) {
       drawShiftTraceMarker(p);
     else if (Preferences::instance()->isOnionSkinEnabled())
       drawOnionSkinSelection(p);
+    // For now, the current frame indicator is not displayed in the xsheet row
+    // area
     else if (Preferences::instance()->isCurrentTimelineIndicatorEnabled() &&
              !m_viewer->orientation()->isVerticalTimeline())
       drawCurrentTimeIndicator(p);
@@ -999,12 +1100,25 @@ void RowArea::mousePressEvent(QMouseEvent *event) {
         playR0       = 0;
       }
 
-      if (playR1 == -1) {  // getFrameCount = 0 i.e. xsheet is empty
+      int playRangeHOffset = 0;
+      if (checkExpandFrameArea()) {
+        playRangeHOffset = m_viewer->orientation()->dimension(
+            PredefinedDimension::FRAME_AREA_EXPANSION);
+      }
+
+      if (xsh->getNavigationTags()->isTagged(row) &&
+          o->rect(PredefinedRect::NAVIGATION_TAG_AREA)
+              .adjusted(0, 0, -frameAdj.x(), -frameAdj.y())
+              .contains(mouseInCell)) {
+        setDragTool(XsheetGUI::DragTool::makeNavigationTagDragTool(m_viewer));
+        frameAreaIsClicked = true;
+      } else if (playR1 == -1) {  // getFrameCount = 0 i.e. xsheet is empty
         setDragTool(
             XsheetGUI::DragTool::makeCurrentFrameModifierTool(m_viewer));
         frameAreaIsClicked = true;
       } else if (o->rect(PredefinedRect::PLAY_RANGE)
                      .adjusted(0, 0, -frameAdj.x(), -frameAdj.y())
+                     .translated(-playRangeHOffset, 0)
                      .contains(mouseInCell) &&
                  (row == playR0 || row == playR1)) {
         if (!playRangeEnabled) XsheetGUI::setPlayRange(playR0, playR1, step);
@@ -1059,7 +1173,8 @@ void RowArea::mouseMoveEvent(QMouseEvent *event) {
     return;
   }
 
-  m_row = m_viewer->xyToPosition(pos).frame();
+  m_row = std::max(0, m_viewer->xyToPosition(pos).frame());
+
   int x = pos.x();
 
   if ((event->buttons() & Qt::LeftButton) != 0 &&
@@ -1162,16 +1277,22 @@ void RowArea::mouseMoveEvent(QMouseEvent *event) {
 
   update();
 
+  int hOffset = 0;
+  if (checkExpandFrameArea()) {
+    hOffset = m_viewer->orientation()->dimension(
+        PredefinedDimension::FRAME_AREA_EXPANSION);
+  }
+
   QPoint base0 = m_viewer->positionToXY(CellPosition(m_r0, -1));
   if (!m_viewer->orientation()->isVerticalTimeline())
     base0.setY(0);
   else
-    base0.setX(0);
+    base0.setX(-hOffset);
   QPoint base1 = m_viewer->positionToXY(CellPosition(m_r1, -1));
   if (!m_viewer->orientation()->isVerticalTimeline())
     base1.setY(0);
   else
-    base1.setX(0);
+    base1.setX(-hOffset);
   QPainterPath startArrow =
       o->path(PredefinedPath::BEGIN_PLAY_RANGE).translated(base0);
   QPainterPath endArrow =
@@ -1186,7 +1307,14 @@ void RowArea::mouseMoveEvent(QMouseEvent *event) {
     m_tooltip = tr("Pinned Center : Col%1%2")
                     .arg(pinnedCenterColumnId + 1)
                     .arg((isRootBonePinned) ? " (Root)" : "");
-  else if (row == currentRow) {
+  else if (o->rect(PredefinedRect::NAVIGATION_TAG_AREA)
+               .adjusted(0, 0, -frameAdj.x(), -frameAdj.y())
+               .contains(mouseInCell)) {
+    TXsheet *xsh  = m_viewer->getXsheet();
+    QString label = xsh->getNavigationTags()->getTagLabel(m_row);
+    if (label.isEmpty()) label = "-";
+    if (xsh->isFrameTagged(m_row)) m_tooltip = tr("Tag: %1").arg(label);
+  } else if (row == currentRow) {
     if (Preferences::instance()->isOnionSkinEnabled() &&
         o->rect(PredefinedRect::ONION)
             .translated(-frameAdj / 2)
@@ -1203,7 +1331,7 @@ void RowArea::mouseMoveEvent(QMouseEvent *event) {
 //-----------------------------------------------------------------------------
 
 void RowArea::mouseReleaseEvent(QMouseEvent *event) {
-  m_viewer->setQtModifiers(0);
+  m_viewer->setQtModifiers(Qt::KeyboardModifiers());
   m_viewer->stopAutoPan();
   m_isPanning = false;
   m_viewer->dragToolRelease(event);
@@ -1261,10 +1389,39 @@ void RowArea::contextMenuEvent(QContextMenuEvent *event) {
   menu->addAction(cmdManager->getAction(MI_DrawingSubBackward));
   menu->addSeparator();
   menu->addAction(cmdManager->getAction(MI_ShiftTrace));
+  menu->addAction(cmdManager->getAction(MI_ShowShiftOrigin));
   menu->addAction(cmdManager->getAction(MI_EditShift));
   menu->addAction(cmdManager->getAction(MI_NoShift));
   menu->addAction(cmdManager->getAction(MI_ResetShift));
 
+  // Tags
+  menu->addSeparator();
+  menu->addAction(cmdManager->getAction(MI_ToggleTaggedFrame));
+  menu->addAction(cmdManager->getAction(MI_EditTaggedFrame));
+
+  QMenu *tagMenu          = menu->addMenu(tr("Tags"));
+  NavigationTags *navTags = m_viewer->getXsheet()->getNavigationTags();
+  QAction *tagAction;
+  if (!navTags->getCount()) {
+    tagAction = tagMenu->addAction("Empty");
+    tagAction->setEnabled(false);
+  } else {
+    std::vector<NavigationTags::Tag> tags = navTags->getTags();
+    for (int i = 0; i < tags.size(); i++) {
+      int frame     = tags[i].m_frame;
+      QString label = tr("Frame %1").arg(frame + 1);
+      if (!tags[i].m_label.isEmpty()) label += ": " + tags[i].m_label;
+      tagAction = tagMenu->addAction(label);
+      tagAction->setData(frame);
+      connect(tagAction, SIGNAL(triggered()), this, SLOT(onJumpToTag()));
+    }
+    tagMenu->addSeparator();
+    tagMenu->addAction(cmdManager->getAction(MI_ClearTags));
+  }
+
+  menu->addAction(cmdManager->getAction(MI_NextTaggedFrame));
+  menu->addAction(cmdManager->getAction(MI_PrevTaggedFrame));
+
   menu->exec(event->globalPos());
 }
 
@@ -1407,4 +1564,11 @@ void RowArea::onRemoveMarkers() {
 
 //-----------------------------------------------------------------------------
 
+void RowArea::onJumpToTag() {
+  QAction *senderAction = qobject_cast<QAction *>(sender());
+  assert(senderAction);
+  int frame = senderAction->data().toInt();
+  m_viewer->setCurrentRow(frame);
+}
+
 }  // namespace XsheetGUI
