@@ -44,6 +44,8 @@ class RowArea final : public QWidget {
   // panning by middle-drag
   bool m_isPanning;
 
+  // returns true if the frame area can have extra space
+  bool checkExpandFrameArea();
   void drawRows(QPainter &p, int r0, int r1);
   void drawPlayRangeBackground(QPainter &p, int r0, int r1);
   void drawPlayRange(QPainter &p, int r0, int r1);
@@ -59,6 +61,8 @@ class RowArea final : public QWidget {
   void drawStopMotionCameraIndicator(QPainter &p);
 #endif
 
+  void drawNavigationTags(QPainter &p, int r0, int r1);
+
   DragTool *getDragTool() const;
   void setDragTool(DragTool *dragTool);
 
@@ -69,11 +73,7 @@ class RowArea final : public QWidget {
   int getNonEmptyCell(int row, int column, Direction);
 
 public:
-#if QT_VERSION >= 0x050500
-  RowArea(XsheetViewer *parent, Qt::WindowFlags flags = 0);
-#else
-  RowArea(XsheetViewer *parent, Qt::WFlags flags = 0);
-#endif
+  RowArea(XsheetViewer *parent, Qt::WindowFlags flags = Qt::WindowFlags());
   ~RowArea();
 
 protected:
@@ -99,6 +99,9 @@ protected slots:
 
   // set both the from and to markers at the specified row
   void onPreviewThis();
+
+protected slots:
+  void onJumpToTag();
 };
 
 }  // namespace XsheetGUI
