@@ -149,7 +149,7 @@ void fillautoInks(TRasterCM32P &rin, TRect &rect, const TRasterCM32P &rbefore,
       int paint = pix->getPaint();
       int tone  = pix->getTone();
       int ink   = pix->getInk();
-      if (paint != pixb->getPaint() && tone > 0 && tone < 255 && ink != paint &&
+      if (paint != pixb->getPaint() && ink != paint &&
           plt->getStyle(ink)->getFlags() != 0)
         inkFill(rin, TPoint(j, i) + rect.getP00(), paint, 0, NULL, &rect);
     }
@@ -161,7 +161,7 @@ void fillautoInks(TRasterCM32P &rin, TRect &rect, const TRasterCM32P &rbefore,
 bool AreaFiller::rectFill(const TRect &rect, int color, bool onlyUnfilled,
                           bool fillPaints, bool fillInks) {
   // Viene trattato il caso fillInks
-  /*- FillInkのみの場合 -*/
+  /*- In case of FillInk only -*/
   if (!fillPaints) {
     assert(fillInks);
     assert(m_ras->getBounds().contains(rect));
@@ -182,7 +182,7 @@ bool AreaFiller::rectFill(const TRect &rect, int color, bool onlyUnfilled,
   std::vector<int> frameSeed(2 * (r.getLx() + r.getLy() - 2));
 
   int x, y, count1, count2;
-  /*- ptrをRect範囲のスタート地点に移動 -*/
+  /*- Move ptr to the start of the Rectangular range -*/
   Pixel *ptr = m_pixels + r.y0 * m_wrap + r.x0;
   count1     = 0;
   count2     = r.y1 - r.y0 + 1;
@@ -195,7 +195,7 @@ bool AreaFiller::rectFill(const TRect &rect, int color, bool onlyUnfilled,
   // Viene riempito frameSeed con tutti i paint delle varie aree del rettangolo
   // di contorno.
   // Viene verificato se i pixels del rettangolo sono tutti pure paint.
-  /*- 輪郭のPaintのIDをframeseed内に格納 -*/
+  /*- Store the Paint ID of the contour in the frameseed -*/
   for (y = r.y0; y <= r.y1; y++, ptr += m_wrap, count1++, count2++) {
     if (r.x0 > 0) frameSeed[count1] = ptr->getPaint();
     if (r.x1 < m_ras->getLx() - 1) frameSeed[count2] = (ptr + dx)->getPaint();
@@ -430,7 +430,7 @@ public:
 
     pix = m_buf + p.y * m_wrap + p.x;
 
-    /*-- 同じインクの場合はreturn --*/
+    /*-- If the same ink is used, RETURN --*/
     if (pix->getInk() == ink) return false;
 
     if (!ConnectionTable[neighboursCode(pix, p)]) {
