@@ -1,5 +1,4 @@
 
-
 #include "toonz/preferences.h"
 
 // TnzLib includes
@@ -27,9 +26,6 @@
 #include <QColor>
 #include <QTextStream>
 
-// boost includes
-#include <boost/bind.hpp>
-
 //**********************************************************************************
 //    Local namespace  stuff
 //**********************************************************************************
@@ -47,7 +43,8 @@ const char *s_name = "name", *s_regexp = "regexp", *s_priority = "priority";
 
 const char *s_dpiPolicy = "dpiPolicy", *s_dpi = "dpi",
            *s_subsampling = "subsampling", *s_antialias = "antialias",
-           *s_premultiply = "premultiply", *s_whiteTransp = "whiteTransp";
+           *s_premultiply = "premultiply", *s_whiteTransp = "whiteTransp",
+           *s_colorSpaceGamma = "colorSpaceGamma";
 
 //=================================================================
 
@@ -124,6 +121,7 @@ void setValue(QSettings &settings, const LevelOptions &lo) {
   settings.setValue(s_antialias, lo.m_antialias);
   settings.setValue(s_premultiply, int(lo.m_premultiply));
   settings.setValue(s_whiteTransp, int(lo.m_whiteTransp));
+  settings.setValue(s_colorSpaceGamma, lo.m_colorSpaceGamma);
 }
 
 //-----------------------------------------------------------------
@@ -138,6 +136,8 @@ void getValue(const QSettings &settings, LevelOptions &lo) {
       (settings.value(s_premultiply, lo.m_premultiply).toInt() != 0);
   lo.m_whiteTransp =
       (settings.value(s_whiteTransp, lo.m_whiteTransp).toInt() != 0);
+  lo.m_colorSpaceGamma =
+      settings.value(s_colorSpaceGamma, lo.m_colorSpaceGamma).toDouble();
 }
 
 //-----------------------------------------------------------------
@@ -388,15 +388,11 @@ void Preferences::definePreferenceItems() {
   define(CurrentStyleSheetName, "CurrentStyleSheetName", QMetaType::QString,
          "Default");
 
-  // Qt has a bug in recent versions that Menu item Does not show correctly
-  // (QTBUG-90242) Since the current OT is made to handle such issue, so we need
-  // to apply an extra adjustment when it is run on the older versions (5.9.x)
-  // of Qt
-  // Update: confirmed that the bug does not appear at least in Qt 5.12.8
+// Qt has a bug in recent versions that Menu item does not show correctly
+// (QTBUG-90242). The current OT handles this issue by applying an extra adjustment
+// for Qt versions 5.9.x.
+// Update: Issue confirmed fixed in Qt 5.12.8 and above, no longer affecting Qt 5.15 and later.
   QString defaultAditionalSheet = "";
-#if QT_VERSION < QT_VERSION_CHECK(5, 12, 9)
-  defaultAditionalSheet = "QMenu::Item{ padding: 3 28 3 28; }";
-#endif
 
   define(additionalStyleSheet, "additionalStyleSheet", QMetaType::QString,
          defaultAditionalSheet);
@@ -452,18 +448,23 @@ void Preferences::definePreferenceItems() {
   setCallBack(linearUnits, &Preferences::setUnits);
   setCallBack(cameraUnits, &Preferences::setCameraUnits);
 
+  define(viewerIndicatorEnabled, "viewerIndicatorEnabled", QMetaType::Bool,
+         true);
+
   // Visualization
   define(show0ThickLines, "show0ThickLines", QMetaType::Bool, true);
   define(regionAntialias, "regionAntialias", QMetaType::Bool, false);
+  define(rasterizeAntialias, "rasterizeAntialias", QMetaType::Bool, true);
 
   // Loading
   define(importPolicy, "importPolicy", QMetaType::Int, 0);  // Always ask
+  define(renamePolicy, "renamePolicy", QMetaType::Int, 0); // Always ask
   define(autoExposeEnabled, "autoExposeEnabled", QMetaType::Bool, true);
   define(subsceneFolderEnabled, "subsceneFolderEnabled", QMetaType::Bool, true);
   define(removeSceneNumberFromLoadedLevelName,
          "removeSceneNumberFromLoadedLevelName", QMetaType::Bool, false);
   define(IgnoreImageDpi, "IgnoreImageDpi", QMetaType::Bool, false);
-  define(initialLoadTlvCachingBehavior, "initialLoadTlvCachingBehavior",
+  define(rasterLevelCachingBehavior, "rasterLevelCachingBehavior",
          QMetaType::Int, 0);  // On Demand
   define(columnIconLoadingPolicy, "columnIconLoadingPolicy", QMetaType::Int,
          (int)LoadAtOnce);
@@ -563,6 +564,10 @@ void Preferences::definePreferenceItems() {
   define(xsheetAutopanEnabled, "xsheetAutopanEnabled", QMetaType::Bool, true);
   define(DragCellsBehaviour, "DragCellsBehaviour", QMetaType::Int,
          1);  // Cells and Column Data
+  define(deleteCommandBehavior, "deleteCommandBehavior", QMetaType::Int,
+         0);  // Clear Cell / Frame
+  define(pasteCellsBehavior, "pasteCellsBehavior", QMetaType::Int,
+         0);  // Insert paste whole cell data
   define(ignoreAlphaonColumn1Enabled, "ignoreAlphaonColumn1Enabled",
          QMetaType::Bool, false);
   define(showKeyframesOnXsheetCellArea, "showKeyframesOnXsheetCellArea",
@@ -576,10 +581,16 @@ void Preferences::definePreferenceItems() {
   define(shortcutCommandsWhileRenamingCellEnabled,
          "shortcutCommandsWhileRenamingCellEnabled", QMetaType::Bool, false);
   define(showXSheetToolbar, "showXSheetToolbar", QMetaType::Bool, true);
+  define(showXsheetBreadcrumbs, "showXsheetBreadcrumbs", QMetaType::Bool,
+         false);
   define(expandFunctionHeader, "expandFunctionHeader", QMetaType::Bool, false);
   define(showColumnNumbers, "showColumnNumbers", QMetaType::Bool, false);
+  define(unifyColumnVisibilityToggles, "unifyColumnVisibilityToggles",
+         QMetaType::Bool, false);
   define(parentColorsInXsheetColumn, "parentColorsInXsheetColumn",
          QMetaType::Bool, false);
+  define(highlightLineEverySecond, "highlightLineEverySecond", QMetaType::Bool,
+         false);
   define(syncLevelRenumberWithXsheet, "syncLevelRenumberWithXsheet",
          QMetaType::Bool, true);
   define(currentTimelineEnabled, "currentTimelineEnabled", QMetaType::Bool,
@@ -592,6 +603,14 @@ void Preferences::definePreferenceItems() {
          0);  // default
   define(showFrameNumberWithLetters, "showFrameNumberWithLetters",
          QMetaType::Bool, false);
+  // This option will do the following:
+  // - When setting a cell in the empty column, level name will be copied to the
+  // column name
+  // - Typing the cell without level name in the empty column will try to use a
+  // level with the same name as the column The behavior may be changed in the
+  // future development.
+  define(linkColumnNameWithLevel, "linkColumnNameWithLevel", QMetaType::Bool,
+         false);
 
   // Animation
   define(keyframeType, "keyframeType", QMetaType::Int, 2);  // Linear
@@ -792,6 +811,16 @@ void Preferences::resolveCompatibility() {
       !m_settings->contains("DefRasterFormat")) {
     setValue(DefRasterFormat, m_settings->value("scanLevelType").toString());
   }
+  // "initialLoadTlvCachingBehavior" is changed to "rasterLevelCachingBehavior"
+  // , Now this setting also applies to raster levels (previously only Toonz
+  // raster levels). It also applies to any operation that loads a level, such
+  // as loading scene or loading a recent level. (Previously, this was only
+  // available from the Load Level popup.)
+  if (m_settings->contains("initialLoadTlvCachingBehavior") &&
+      !m_settings->contains("rasterLevelCachingBehavior")) {
+    setValue(rasterLevelCachingBehavior,
+             m_settings->value("initialLoadTlvCachingBehavior").toInt());
+  }
 }
 
 //-----------------------------------------------------------------
@@ -963,8 +992,10 @@ void Preferences::setRasterBackgroundColor() {
 //-----------------------------------------------------------------
 
 void Preferences::storeOldUnits() {
-  setValue(oldUnits, getStringValue(linearUnits));
-  setValue(oldCameraUnits, getStringValue(cameraUnits));
+  QString linearU = getStringValue(linearUnits);
+  if (linearU != "pixel") setValue(oldUnits, linearU);
+  QString cameraU = getStringValue(cameraUnits);
+  if (cameraU != "pixel") setValue(oldCameraUnits, cameraU);
 }
 
 //-----------------------------------------------------------------
@@ -992,30 +1023,28 @@ QString Preferences::getCurrentLanguage() const {
 QString Preferences::getCurrentStyleSheet() const {
   QString currentStyleSheetName = getStringValue(CurrentStyleSheetName);
   if (currentStyleSheetName.isEmpty()) return QString();
+
   TFilePath path(TEnv::getConfigDir() + "qss");
   QString string = currentStyleSheetName + QString("/") +
                    currentStyleSheetName + QString(".qss");
   QString styleSheetPath = path.getQString() + "/" + string;
 
-  QString additionalSheetStr = getStringValue(additionalStyleSheet);
-  // if there is no additional style sheet, return the path and let
-  // Qt to load and parse it
-  if (additionalSheetStr.isEmpty()) return QString("file:///" + styleSheetPath);
-
-  // if there is any additional style sheet, load the style sheet
-  // from the file and combine with it
   QString styleSheetStr;
+
+  // Always read the main stylesheet from the file
   QFile f(styleSheetPath);
   if (f.open(QFile::ReadOnly | QFile::Text)) {
     QTextStream ts(&f);
     styleSheetStr = ts.readAll();
   }
-  styleSheetStr += additionalSheetStr;
 
-  // here we will convert all relative paths to absolute paths
-  // or Qt will look for images relative to the current working directory
-  // since it has no idea where the style sheet comes from.
+  // Append additional stylesheet if provided
+  QString additionalSheetStr = getStringValue(additionalStyleSheet);
+  if (!additionalSheetStr.isEmpty()) {
+    styleSheetStr += additionalSheetStr;
+  }
 
+  // Fix relative paths in stylesheets
   QString currentStyleFolderPath =
       path.getQString().replace("\\", "/") + "/" + currentStyleSheetName;
 
@@ -1074,7 +1103,7 @@ int Preferences::levelFormatsCount() const {
 int Preferences::matchLevelFormat(const TFilePath &fp) const {
   LevelFormatVector::const_iterator lft =
       std::find_if(m_levelFormats.begin(), m_levelFormats.end(),
-                   boost::bind(&LevelFormat::matches, _1, boost::cref(fp)));
+                   [&fp](const LevelFormat &format) { return format.matches(fp); });
 
   return (lft != m_levelFormats.end()) ? lft - m_levelFormats.begin() : -1;
 }
