@@ -1,7 +1,7 @@
 
 
 #include "toonzqt/menubarcommand.h"
-//#include "menubarcommandids.h"
+// #include "menubarcommandids.h"
 #include "toonzqt/dvdialog.h"
 #include "toonzqt/gutil.h"
 #include "toonz/toonzfolders.h"
@@ -111,8 +111,8 @@ void CommandManager::setShortcut(CommandId id, QAction *action,
 //---------------------------------------------------------
 
 void CommandManager::define(CommandId id, CommandType type,
-                            std::string defaultShortcutString,
-                            QAction *qaction) {
+                            std::string defaultShortcutString, QAction *qaction,
+                            const char *iconSVGName) {
   assert(type != UndefinedCommandType);
   assert(qaction != 0);
   assert(m_qactionTable.count(qaction) == 0);
@@ -129,6 +129,7 @@ void CommandManager::define(CommandId id, CommandType type,
       node->m_type == MiscCommandType ||
       node->m_type == ToolModifierCommandType ||
       node->m_type == CellMarkCommandType);
+  node->m_iconSVGName = iconSVGName;
 
   m_qactionTable[qaction] = node;
   qaction->setShortcutContext(Qt::ApplicationShortcut);
@@ -385,41 +386,109 @@ std::string CommandManager::getIdFromAction(QAction *action) {
     return "";
 }
 
+//---------------------------------------------------------
+
+const char *CommandManager::getIconSVGName(CommandId id) {
+  Node *node = getNode(id, false);
+  if (node) return node->m_iconSVGName;
+  return "";
+}
+
+void CommandManager::enlargeIcon(CommandId id, const QSize dstSize) {
+  QAction *action = getAction(id, false);
+  if (!action) return;
+
+  const char *iconSVGName = getIconSVGName(id);
+  if (strcmp(iconSVGName, "") == 0) return;
+
+  QIcon icon = action->icon();
+
+  for (QList<QSize> sizes = icon.availableSizes(); !sizes.isEmpty();
+       sizes.removeFirst()) {
+    if (sizes.first().width() > dstSize.width() &&
+        sizes.first().height() > dstSize.height())
+      return;
+  }
+
+  action->setIcon(icon);
+}
+
 //---------------------------------------------------------
 // load user defined shortcuts
 
+// In menubarcommand.cpp
 void CommandManager::loadShortcuts() {
+  // Define reserved navigation shortcuts
+  const std::vector<std::string> reservedKeys = {"Space", "Shift+Space",
+                                                 "Ctrl+Space"};
+
+  // Load shortcuts file
   TFilePath fp = ToonzFolder::getMyModuleDir() + TFilePath("shortcuts.ini");
+
   if (!TFileStatus(fp).doesExist()) {
-    // if user shortcut file does not exist, then try to load from template
     TFilePath tmplFp =
         ToonzFolder::getTemplateModuleDir() + TFilePath("shortcuts.ini");
-    if (TFileStatus(tmplFp).doesExist()) TSystem::copyFile(fp, tmplFp);
-    // if neither settings exist, do nothing and return
-    else
+    if (TFileStatus(tmplFp).doesExist()) {
+      TSystem::copyFile(fp, tmplFp);
+    } else {
       return;
+    }
   }
 
   QSettings settings(toQString(fp), QSettings::IniFormat);
   settings.beginGroup("shortcuts");
   QStringList ids = settings.allKeys();
+
   for (int i = 0; i < ids.size(); i++) {
     std::string id   = ids.at(i).toStdString();
     QString shortcut = settings.value(ids.at(i), "").toString();
-    QAction *action  = getAction(&id[0], false);
+
+    // Check if this is a reserved navigation shortcut
+    bool isReserved = false;
+    for (const std::string &reserved : reservedKeys) {
+      if (shortcut.toStdString() == reserved) {
+        isReserved = true;
+        break;
+      }
+    }
+
+    QAction *action = getAction(&id[0], false);
+
+    if (isReserved) {
+      // Remove reserved shortcuts
+      settings.remove(ids.at(i));
+      if (action) {
+        action->setShortcut(QKeySequence());
+      }
+      continue;
+    }
+
+    // Process non-reserved shortcuts
     if (action) {
       QString oldShortcut = action->shortcut().toString();
-      if (oldShortcut == shortcut) continue;
-      if (!oldShortcut.isEmpty())
+
+      if (oldShortcut == shortcut) {
+        continue;
+      }
+
+      // Remove old shortcut mapping
+      if (!oldShortcut.isEmpty()) {
         m_shortcutTable.erase(oldShortcut.toStdString());
+      }
+
+      // Set new shortcut
       if (!shortcut.isEmpty()) {
         QAction *other = getActionFromShortcut(shortcut.toStdString());
-        if (other) other->setShortcut(QKeySequence());
+        if (other) {
+          other->setShortcut(QKeySequence());
+        }
         m_shortcutTable[shortcut.toStdString()] = getNode(&id[0]);
       }
+
       action->setShortcut(QKeySequence(shortcut));
     }
   }
+
   settings.endGroup();
 }
 
@@ -483,8 +552,10 @@ void DVAction::onTriggered() { CommandManager::instance()->execute(this); }
                 is helpful to use \b m_triggeredActionIndex to distingue action.
 */
 DVMenuAction::DVMenuAction(const QString &text, QWidget *parent,
-                           QList<QString> actions)
-    : QMenu(text, parent), m_triggeredActionIndex(-1) {
+                           QList<QString> actions, bool isForRecentFiles)
+    : QMenu(text, parent)
+    , m_triggeredActionIndex(-1)
+    , m_isForRecentFiles(isForRecentFiles) {
   int i;
   for (i = 0; i < actions.size(); i++) addAction(actions.at(i));
   connect(this, SIGNAL(triggered(QAction *)), this,
@@ -535,6 +606,13 @@ void DVMenuAction::onTriggered(QAction *action) {
   QVariant data = action->data();
   if (data.isValid()) m_triggeredActionIndex = data.toInt();
   CommandManager::instance()->execute(action, menuAction());
+
+  // simply execute the menu item and return
+  if (!m_isForRecentFiles) {
+    m_triggeredActionIndex = -1;
+    return;
+  }
+
   int oldIndex = m_triggeredActionIndex;
   if (m_triggeredActionIndex != -1) m_triggeredActionIndex = -1;
   QString str = data.toString();
