@@ -249,11 +249,7 @@ void PanTool::release(int row, int col, QMouseEvent *e) {
 
 //=============================================================================
 
-#if QT_VERSION >= 0x050500
 ScrollArea::ScrollArea(QWidget *parent, Qt::WindowFlags flags)
-#else
-ScrollArea::ScrollArea(QWidget *parent, Qt::WFlags flags)
-#endif
     : QScrollArea(parent) {
   setFrameStyle(QFrame::Panel | QFrame::Raised);
   setLineWidth(6);
@@ -294,7 +290,7 @@ void GenericPanel::paintEvent(QPaintEvent *e) {
 
 void GenericPanel::mousePressEvent(QMouseEvent *e) {
   assert(!m_dragTool);
-  if (e->button() == Qt::MidButton)
+  if (e->button() == Qt::MiddleButton)
     m_dragTool = new PanTool(this);
   else
     m_dragTool = createDragTool(e);
@@ -371,15 +367,22 @@ void RowPanel::drawRows(QPainter &p, int r0, int r1) {
   bool simpleView = getViewer()->getFrameZoomFactor() <=
                     Orientations::topToBottom()->dimension(
                         PredefinedDimension::SCALE_THRESHOLD);
+  int currentRow = getViewer()->getCurrentRow();
   int r;
   int y = getViewer()->rowToY(r0);
   for (r = r0; r <= r1; r++) {
     int next_y = getViewer()->rowToY(r + 1);
     // draw horizontal line
-    QColor color = (getViewer()->isMarkRow(r))
-                       ? getViewer()->getMarkerLineColor()
-                       : getViewer()->getLightLineColor();
-    p.setPen(color);
+    bool isMarkSecRow = getViewer()->isMarkSecRow(r);
+    bool isMarkRow    = getViewer()->isMarkRow(r);
+    QColor color      = (isMarkSecRow) ? getViewer()->getSecMarkerLineColor()
+                        : (isMarkRow)  ? getViewer()->getMarkerLineColor()
+                                       : getViewer()->getLightLineColor();
+    p.setPen(QPen(color,
+                  (isMarkSecRow)                                    ? 3.
+                  : (getViewer()->isSecMarkerActive() && isMarkRow) ? 2.
+                                                                    : 1.,
+                  Qt::SolidLine, Qt::FlatCap));
     p.drawLine(x0, y, x1, y);
 
     if (simpleView && r > 0 && !getViewer()->isMarkRow(r + 1)) {
@@ -388,18 +391,14 @@ void RowPanel::drawRows(QPainter &p, int r0, int r1) {
     }
 
     // draw numbers
-    p.setPen(getViewer()->getTextColor());
+    p.setPen((r == currentRow) ? getViewer()->getCurrentRowTextColor()
+                               : getViewer()->getFrameTextColor());
 
     QString number = QString::number(r + 1);
     p.drawText(QRect(x0, y + 1, width() - 4, next_y - y - 1),
                Qt::AlignVCenter | Qt::AlignRight, number);
     y = next_y;
   }
-  // erase the marker interval at upper-end
-  if (r0 == 0) {
-    p.setPen(getViewer()->getLightLineColor());
-    p.drawLine(x0, getViewer()->rowToY(0), x1, getViewer()->rowToY(0));
-  }
 }
 
 //-----------------------------------------------------------------------------
@@ -493,15 +492,19 @@ void CellPanel::paintEvent(QPaintEvent *e) {
   // draw rows
   int currentRow = getViewer()->getCurrentRow();
   for (int r = r0; r <= r1; r++) {
-    int y        = getViewer()->rowToY(r);
-    QColor color = getViewer()->isMarkRow(r) ? getViewer()->getMarkerLineColor()
-                                             : getViewer()->getLightLineColor();
-    painter.setPen(color);
+    int y             = getViewer()->rowToY(r);
+    bool isMarkSecRow = getViewer()->isMarkSecRow(r);
+    bool isMarkRow    = getViewer()->isMarkRow(r);
+    QColor color      = (isMarkSecRow) ? getViewer()->getSecMarkerLineColor()
+                        : (isMarkRow)  ? getViewer()->getMarkerLineColor()
+                                       : getViewer()->getLightLineColor();
+    painter.setPen(QPen(color,
+                        (isMarkSecRow)                                    ? 3.
+                        : (getViewer()->isSecMarkerActive() && isMarkRow) ? 2.
+                                                                          : 1.,
+                        Qt::SolidLine, Qt::FlatCap));
     painter.drawLine(x0, y, x1, y);
   }
-  // erase the marker interval at upper-end
-  painter.setPen(getViewer()->getLightLineColor());
-  painter.drawLine(x0, 0, x1, 0);
 }
 
 }  // namespace Spreadsheet
@@ -525,6 +528,7 @@ SpreadsheetViewer::SpreadsheetViewer(QWidget *parent)
     , m_currentRow(0)
     , m_markRowDistance(6)
     , m_markRowOffset(0)
+    , m_markSecRowDistance(-1)
     , m_isComputingSize(false)
     , m_frameScroller() {
   // m_orientation = Orientations::topToBottom ();
@@ -804,7 +808,7 @@ bool SpreadsheetViewer::refreshContentSize(int scrollDx, int scrollDy) {
   QSize viewportSize = m_cellScrollArea->viewport()->size();
   QPoint offset      = m_cellScrollArea->widget()->pos();
   offset             = QPoint(std::min(0, offset.x() - scrollDx),
-                  std::min(0, offset.y() - scrollDy));
+                              std::min(0, offset.y() - scrollDy));
 
   QSize contentSize(columnToX(m_columnCount + 1), rowToY(m_rowCount + 1));
 
