@@ -489,6 +489,11 @@ Wahrscheinlich funktioniert der Codec nicht korrekt.</translation>
         <source>White</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Custom Texture</source>
+        <comment>TextureStyleChooserPage</comment>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>TScriptBinding::CenterlineVectorizer</name>
