@@ -87,6 +87,22 @@
         <source>Table</source>
         <translation>テーブル</translation>
     </message>
+    <message>
+        <source>Flip Object Horizontally</source>
+        <translation>水平方向に反転</translation>
+    </message>
+    <message>
+        <source>Flip Object Vertically</source>
+        <translation>垂直方向に反転</translation>
+    </message>
+    <message>
+        <source>Rotate Object Left</source>
+        <translation>90°回転（反時計回り）</translation>
+    </message>
+    <message>
+        <source>Rotate Object Right</source>
+        <translation>90°回転（時計回り）</translation>
+    </message>
 </context>
 <context>
     <name>BrushTool</name>
@@ -583,6 +599,10 @@
         <source>Maximum Gap</source>
         <translation>隙間の判定</translation>
     </message>
+    <message>
+        <source>Pick+Freehand</source>
+        <translation>スポイト＋なげなわ</translation>
+    </message>
 </context>
 <context>
     <name>FingerTool</name>
@@ -1466,6 +1486,22 @@ Do you want to proceed?</source>
         <source>Position</source>
         <translation>位置</translation>
     </message>
+    <message>
+        <source>Flip Selection Horizontally</source>
+        <translation>選択範囲を水平方向に反転</translation>
+    </message>
+    <message>
+        <source>Flip Selection Vertically</source>
+        <translation>選択範囲を垂直方向に反転</translation>
+    </message>
+    <message>
+        <source>Rotate Selection Left</source>
+        <translation>選択範囲を90°回転（反時計回り）</translation>
+    </message>
+    <message>
+        <source>Rotate Selection Right</source>
+        <translation>選択範囲を90°回転（時計回り）</translation>
+    </message>
 </context>
 <context>
     <name>ShiftTraceToolOptionBox</name>
