@@ -1,6 +1,21 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="ko" sourcelanguage="en">
+<TS version="2.0" language="ko" sourcelanguage="en">
+<context>
+    <name>APngWriterProperties</name>
+    <message>
+        <source>Scale</source>
+        <translation>비율</translation>
+    </message>
+    <message>
+        <source>Looping</source>
+        <translation>반복</translation>
+    </message>
+    <message>
+        <source>Write as .png</source>
+        <translation>.PNG로 작성하기</translation>
+    </message>
+</context>
 <context>
     <name>AviWriterProperties</name>
     <message>
@@ -62,6 +77,29 @@
         <source>Tile based</source>
         <translation>티일기반</translation>
     </message>
+    <message>
+        <source>96(RGB Float)</source>
+        <translation>96(RGB Float)</translation>
+    </message>
+    <message>
+        <source>128(RGBA Float)</source>
+        <translation>128(RGBA Float)</translation>
+    </message>
+    <message>
+        <source>Color Space Gamma</source>
+        <translation>색상 공간 감마</translation>
+    </message>
+</context>
+<context>
+    <name>FFMovWriterProperties</name>
+    <message>
+        <source>Quality</source>
+        <translation>품질</translation>
+    </message>
+    <message>
+        <source>Scale</source>
+        <translation>비율</translation>
+    </message>
 </context>
 <context>
     <name>GifWriterProperties</name>
@@ -75,7 +113,7 @@
     </message>
     <message>
         <source>Generate Palette</source>
-        <translation type="vanished">팔레트 생성</translation>
+        <translation>팔레트 생성</translation>
     </message>
     <message>
         <source>Global Palette</source>
@@ -199,7 +237,7 @@ Please try raising the FFmpeg timeout in Preferences.</source>
         <translation>8비트</translation>
     </message>
     <message>
-        <source>Endianess</source>
+        <source>Endianness</source>
         <translation>엔디안</translation>
     </message>
     <message>
