@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="ko" sourcelanguage="en">
+<TS version="2.0" language="ko" sourcelanguage="en">
 <context>
     <name>AddFxContextMenu</name>
     <message>
@@ -127,7 +127,7 @@
         <source>&apos;%1&apos; doesn&apos;t seem a well formed camera preset. 
 Possibly the preset file has been corrupted</source>
         <translation>%1은 잘 형성된 카메라 사전 설정으로 보임. 
-사전 설정 파일이 손상되었을 수 있음.</translation>
+사전 설정 파일이 손상되었을 수 있음</translation>
     </message>
     <message>
         <source>Preset name</source>
@@ -204,7 +204,7 @@ Possibly the preset file has been corrupted</source>
     <name>ColorChannelControl</name>
     <message>
         <source>H</source>
-        <translation type="vanished">수평</translation>
+        <translation>수평</translation>
     </message>
 </context>
 <context>
@@ -218,7 +218,15 @@ Possibly the preset file has been corrupted</source>
     <name>ComboHistoRGBLabel</name>
     <message>
         <source>R:%1 G:%2 B:%3</source>
-        <translation></translation>
+        <translation>R:%1 G:%2 B:%3</translation>
+    </message>
+    <message>
+        <source> A:%1</source>
+        <translation> A:%1</translation>
+    </message>
+    <message>
+        <source>A:%1</source>
+        <translation>A:%1</translation>
     </message>
 </context>
 <context>
@@ -256,11 +264,11 @@ Possibly the preset file has been corrupted</source>
     <name>DVGui</name>
     <message>
         <source>OK</source>
-        <translation type="vanished">네</translation>
+        <translation>네</translation>
     </message>
     <message>
         <source>Cancel</source>
-        <translation type="vanished">취소</translation>
+        <translation>취소</translation>
     </message>
 </context>
 <context>
@@ -442,7 +450,7 @@ Possibly the preset file has been corrupted</source>
     <name>DVGui::LineEdit</name>
     <message>
         <source>A file name cannot contains any of the following chracters: /\:*?&quot;&lt;&gt;|.</source>
-        <translation type="vanished">파일 이름에는 다음 문자 중 어느 것도 포함될 수 없음: /\:*?&quot;&lt;&gt;|.</translation>
+        <translation>파일 이름에는 다음 문자 중 어느 것도 포함될 수 없음: /\:*?&quot;&lt;&gt;|.</translation>
     </message>
     <message>
         <source>A file name cannot contains any of the following characters: /\:*?&quot;&lt;&gt;|.</source>
@@ -508,27 +516,27 @@ Possibly the preset file has been corrupted</source>
     <name>DvTextEdit</name>
     <message>
         <source>Bold</source>
-        <translation type="vanished">볼드</translation>
+        <translation>볼드</translation>
     </message>
     <message>
         <source>Italic</source>
-        <translation type="vanished">이탤릭체</translation>
+        <translation>이탤릭체</translation>
     </message>
     <message>
         <source>Underline</source>
-        <translation type="vanished">밑줄</translation>
+        <translation>밑줄</translation>
     </message>
     <message>
         <source>Align Left</source>
-        <translation type="vanished">왼쪽 정렬</translation>
+        <translation>왼쪽 정렬</translation>
     </message>
     <message>
         <source>Align Center</source>
-        <translation type="vanished">중심 정렬</translation>
+        <translation>중심 정렬</translation>
     </message>
     <message>
         <source>Align Right</source>
-        <translation type="vanished">오른쪽 정렬</translation>
+        <translation>오른쪽 정렬</translation>
     </message>
 </context>
 <context>
@@ -680,7 +688,7 @@ Possibly the preset file has been corrupted</source>
     </message>
     <message>
         <source>&amp;Next frame</source>
-        <translation type="vanished">다음 프레임(&amp;N)</translation>
+        <translation>다음 프레임(&amp;N)</translation>
     </message>
     <message>
         <source>&amp;Last Frame</source>
@@ -740,7 +748,7 @@ Possibly the preset file has been corrupted</source>
     </message>
     <message>
         <source>Drag to play the animation</source>
-        <translation>애니메이션을 재생하려면 끌어서 놓으세요.</translation>
+        <translation>애니메이션을 재생하려면 끌어서 놓으세요</translation>
     </message>
     <message>
         <source>Set the playback frame rate</source>
@@ -782,6 +790,28 @@ Possibly the preset file has been corrupted</source>
         <source>&amp;Next Frame</source>
         <translation>다음 프레임(&amp;N)</translation>
     </message>
+    <message>
+        <source>Gain Controls</source>
+        <translation>게인 컨트롤</translation>
+    </message>
+    <message>
+        <source>&amp;Reduce gain 1/2 stop (divide by sqrt(2))</source>
+        <translation>&amp;이득 1/2 스톱 감소(제곱(2)으로 나누기)</translation>
+    </message>
+    <message>
+        <source>Toggle gain between 1 and the previous setting.
+Gain is shown as an f-stop and the &quot;neutral&quot; or 1.0 gain f-stop is f/8.</source>
+        <translation>게임을 1과 이전 설정 사이에서 전환합니다.
+게인은 F-스톱으로 표시되며 &quot;중립&quot; 또는 1.0 게인 F-스톱은 F.8입니다.</translation>
+    </message>
+    <message>
+        <source>&amp;Increase gain 1/2 stop (multiply by sqrt(2))</source>
+        <translation>&amp;증가 게인 1/2스톱(곱하기 sqrt(2))</translation>
+    </message>
+    <message>
+        <source> (gain %1)</source>
+        <translation>(dlemr %1)</translation>
+    </message>
 </context>
 <context>
     <name>FontParamField</name>
@@ -1095,19 +1125,19 @@ Possibly the preset file has been corrupted</source>
     </message>
     <message>
         <source>Step 1</source>
-        <translation type="vanished">1단계</translation>
+        <translation>1단계</translation>
     </message>
     <message>
         <source>Step 2</source>
-        <translation type="vanished">2단계</translation>
+        <translation>2단계</translation>
     </message>
     <message>
         <source>Step 3</source>
-        <translation type="vanished">3단계</translation>
+        <translation>3단계</translation>
     </message>
     <message>
         <source>Step 4</source>
-        <translation type="vanished">4단계</translation>
+        <translation>4단계</translation>
     </message>
     <message>
         <source>Activate Cycle</source>
@@ -1515,14 +1545,14 @@ Select FX nodes and related links before copying or cutting the selection you wa
     <name>LineEdit</name>
     <message>
         <source>A file name cannot contains any of the following chracters: /\:*?&quot;&lt;&gt;|.</source>
-        <translation type="vanished">파일 이름에는 다음 문자 중 어느 것도 포함될 수 없음: /\:*?&quot;&lt;&gt;|.</translation>
+        <translation>파일 이름에는 다음 문자 중 어느 것도 포함될 수 없음: /\:*?&quot;&lt;&gt;|.</translation>
     </message>
 </context>
 <context>
     <name>MyPaintBrushStyleChooserPage</name>
     <message>
         <source>Plain color</source>
-        <translation type="vanished">일반 색상</translation>
+        <translation>일반 색상</translation>
     </message>
 </context>
 <context>
@@ -1544,19 +1574,19 @@ Select FX nodes and related links before copying or cutting the selection you wa
     <name>PageViewer</name>
     <message>
         <source>- No Styles -</source>
-        <translation type="vanished">- 스타일 없음 -</translation>
+        <translation>- 스타일 없음 -</translation>
     </message>
     <message>
         <source>Name Editor</source>
-        <translation type="vanished">이름 편집기</translation>
+        <translation>이름 편집기</translation>
     </message>
     <message>
         <source>New Style</source>
-        <translation type="vanished">새로운 스타일</translation>
+        <translation>새로운 스타일</translation>
     </message>
     <message>
         <source>New Page</source>
-        <translation type="vanished">새로운 페이지</translation>
+        <translation>새로운 페이지</translation>
     </message>
 </context>
 <context>
@@ -1685,6 +1715,30 @@ Select FX nodes and related links before copying or cutting the selection you wa
         <source>Set Toolbar Above Styles</source>
         <translation>스타일 위에 도구 모음 설정</translation>
     </message>
+    <message>
+        <source>Auto Adjust Panel Width</source>
+        <translation>패널 너비자동조정</translation>
+    </message>
+    <message>
+        <source>Visible Toolbar Buttons</source>
+        <translation>표시되는 도구 모음 버튼</translation>
+    </message>
+    <message>
+        <source>KeyFrame</source>
+        <translation>키 프레임</translation>
+    </message>
+    <message>
+        <source>New Style/Page</source>
+        <translation>새로운 스타일/페이지</translation>
+    </message>
+    <message>
+        <source>Palette Gizmo</source>
+        <translation>팔레트 기즈모</translation>
+    </message>
+    <message>
+        <source>Name Editor</source>
+        <translation>이름 편집기</translation>
+    </message>
 </context>
 <context>
     <name>PaletteViewerGUI::PageViewer</name>
@@ -1743,12 +1797,19 @@ Select FX nodes and related links before copying or cutting the selection you wa
     <name>ParamsPageSet</name>
     <message>
         <source>Fx Help</source>
-        <translation type="vanished">Fx 도움말</translation>
+        <translation>Fx 도움말</translation>
     </message>
     <message>
         <source>View help page</source>
         <translation>도움말 페이지 보기</translation>
     </message>
+    <message>
+        <source>This Fx does not support rendering in floating point channel width (32bit).
+The output pixel values from this fx will be clamped to 0.0 - 1.0
+and tone may be slightly discretized.</source>
+        <translation>이 Fx는 부동 소수점 채널 너비(32비트)로 랜더링을 지원하지 않습니다.
+이 Fx의 출력 픽셀 값은 0.0 ~ 1.0으로 클램핑되며, 톤이 약간 불연속화될 수 있습니다.</translation>
+    </message>
 </context>
 <context>
     <name>PegbarPainter</name>
@@ -1783,7 +1844,7 @@ Select FX nodes and related links before copying or cutting the selection you wa
     <name>ProgressDialog</name>
     <message>
         <source>OpenToonz</source>
-        <translation type="vanished">오픈툰즈</translation>
+        <translation>오픈툰즈</translation>
     </message>
 </context>
 <context>
@@ -1823,7 +1884,7 @@ Are you sure?</source>
     </message>
     <message>
         <source>Can&apos;t paste styles there</source>
-        <translation>스타일을 붙여넣을 수 없음.</translation>
+        <translation>스타일을 붙여넣을 수 없음</translation>
     </message>
     <message>
         <source>  to Palette : %1</source>
@@ -1847,7 +1908,7 @@ Are you sure?</source>
     </message>
     <message>
         <source>Can&apos;t modify color #0</source>
-        <translation>색상 수정할 수 없음.</translation>
+        <translation>색상 수정할 수 없음</translation>
     </message>
     <message>
         <source>There are more cut/copied styles than selected. Paste anyway (adding styles)?</source>
@@ -1927,23 +1988,23 @@ Are you sure?</source>
     </message>
     <message>
         <source>Save</source>
-        <translation type="vanished">저장</translation>
+        <translation>저장</translation>
     </message>
     <message>
         <source>Discard</source>
-        <translation type="vanished">삭제</translation>
+        <translation>삭제</translation>
     </message>
     <message>
         <source>Yes</source>
-        <translation type="vanished">네</translation>
+        <translation>네</translation>
     </message>
     <message>
         <source>No</source>
-        <translation type="vanished">아니요</translation>
+        <translation>아니요</translation>
     </message>
     <message>
         <source>Replace</source>
-        <translation type="vanished">교체</translation>
+        <translation>교체</translation>
     </message>
     <message>
         <source>Modify Fx Param : %1</source>
@@ -1991,7 +2052,7 @@ Are you sure?</source>
     </message>
     <message>
         <source>Palette</source>
-        <translation type="vanished">팔레트</translation>
+        <translation>팔레트</translation>
     </message>
     <message>
         <source>Overwrite</source>
@@ -2118,7 +2179,7 @@ Are you sure?</source>
         <translation>출력 경로: </translation>
     </message>
     <message>
-        <source>Endianess:      </source>
+        <source>Endianness:      </source>
         <translation>엔디언: </translation>
     </message>
     <message>
@@ -2151,7 +2212,7 @@ Are you sure?</source>
     </message>
     <message>
         <source>It is not possible to find the level %1</source>
-        <translation>%1 레벨을 찾을 수 없음.</translation>
+        <translation>%1 레벨을 찾을 수 없음</translation>
     </message>
     <message>
         <source>Cannot premultiply the selected file.</source>
@@ -2167,11 +2228,11 @@ Are you sure?</source>
     </message>
     <message>
         <source>Frame %1 : conversion failed!</source>
-        <translation>프레임 %1: 변환실패</translation>
+        <translation>프레임 %1: 변환실패!</translation>
     </message>
     <message>
         <source>The source image seems not suitable for this kind of conversion</source>
-        <translation>소스 이미지는 이러한 종류의 변환에 적합하지 않는 것으로 보임.</translation>
+        <translation>소스 이미지는 이러한 종류의 변환에 적합하지 않는 것으로 보임</translation>
     </message>
     <message>
         <source>The file name cannot be empty or contain any of the following characters: (new line) \ / : * ? &quot; |</source>
@@ -2179,7 +2240,7 @@ Are you sure?</source>
     </message>
     <message>
         <source>OpenToonz 1.3</source>
-        <translation type="vanished">오픈툰즈 1.3</translation>
+        <translation>오픈툰즈 1.3</translation>
     </message>
     <message>
         <source>Information</source>
@@ -2256,12 +2317,12 @@ Are you sure?</source>
     <message>
         <source>Failed to get attribute location of %1</source>
         <comment>gl</comment>
-        <translation>%1의 속성 위치를 가져오지 못함.</translation>
+        <translation>%1의 속성 위치를 가져오지 못함</translation>
     </message>
     <message>
         <source>Failed to get uniform location of %1</source>
         <comment>gl</comment>
-        <translation>%1의 동일한 위치를 가져오지 못함.</translation>
+        <translation>%1의 동일한 위치를 가져오지 못함</translation>
     </message>
     <message>
         <source>Failed to Open 3DLUT File.</source>
@@ -2333,7 +2394,7 @@ The second line should be &quot;Mesh [Input bit depth] [Output bit depth]&quot;<
     </message>
     <message>
         <source>and %1 more styles.</source>
-        <translation>그리고 % 1 더 많은 스타일.</translation>
+        <translation>스타일이 %1개 더 있습니다.</translation>
     </message>
     <message>
         <source>Erasing unused styles with following indices. Are you sure?
@@ -2351,6 +2412,15 @@ The second line should be &quot;Mesh [Input bit depth] [Output bit depth]&quot;<
         <source>Click &amp; Drag Palette into Studio Palette</source>
         <translation>팔레트를 클릭하여 스튜디오 팔레트로 끌어오기</translation>
     </message>
+    <message>
+        <source>Plain color</source>
+        <comment>TextureStyleChooserPage</comment>
+        <translation>일반 색상</translation>
+    </message>
+    <message>
+        <source>Sample Type: </source>
+        <translation>샘플 유형:</translation>
+    </message>
 </context>
 <context>
     <name>QPushButton</name>
@@ -2363,7 +2433,7 @@ The second line should be &quot;Mesh [Input bit depth] [Output bit depth]&quot;<
     <name>RadioButtonDialog</name>
     <message>
         <source>OpenToonz</source>
-        <translation type="vanished">오픈툰즈</translation>
+        <translation>오픈툰즈</translation>
     </message>
 </context>
 <context>
@@ -2377,6 +2447,29 @@ The second line should be &quot;Mesh [Input bit depth] [Output bit depth]&quot;<
         <translation>스완%1과 %2</translation>
     </message>
 </context>
+<context>
+    <name>SchematicName</name>
+    <message>
+        <source>Cu&amp;t</source>
+        <translation>Cu&amp;t</translation>
+    </message>
+    <message>
+        <source>&amp;Copy</source>
+        <translation>&amp;복사</translation>
+    </message>
+    <message>
+        <source>&amp;Paste</source>
+        <translation>&amp;붙여넣기</translation>
+    </message>
+    <message>
+        <source>&amp;Delete</source>
+        <translation>삭제(&amp;D)</translation>
+    </message>
+    <message>
+        <source>Select &amp;All</source>
+        <translation>&amp;모두선택</translation>
+    </message>
+</context>
 <context>
     <name>SchematicViewer</name>
     <message>
@@ -2417,7 +2510,7 @@ The second line should be &quot;Mesh [Input bit depth] [Output bit depth]&quot;<
     </message>
     <message>
         <source>&amp;Swtich output port display mode</source>
-        <translation type="vanished">스위치 출력 포트 표시모드(&amp;S)</translation>
+        <translation>스위치 출력 포트 표시모드(&amp;S)</translation>
     </message>
     <message>
         <source>&amp;Toggle node icons</source>
@@ -2447,11 +2540,38 @@ The second line should be &quot;Mesh [Input bit depth] [Output bit depth]&quot;<
         <translation>편집기 닫기(&amp;C)</translation>
     </message>
 </context>
+<context>
+    <name>SeeThroughWindowPopup</name>
+    <message>
+        <source>See Through Mode (Main Window)</source>
+        <translation>투시모드(기본창)</translation>
+    </message>
+    <message>
+        <source>Opacity</source>
+        <translation>불투명도</translation>
+    </message>
+    <message>
+        <source>Quickly toggle main window semi-transparency and full opacity.</source>
+        <translation>기본 창 반투명도와 전체 불투명도를 빠르게 전환할 수 있습니다.</translation>
+    </message>
+    <message>
+        <source>Hold ALT while clicking to use full transparency instead.</source>
+        <translation>전체 투명도를 사용하려면 클릭하는 동안 Alt 키를 누르고 있습니다.</translation>
+    </message>
+    <message>
+        <source>When slider is at 100% it acts as ALT is held.</source>
+        <translation>슬라이더를 100%로 설정하면 ALT를 누른 상태로 작동합니다.</translation>
+    </message>
+    <message>
+        <source>Close</source>
+        <translation>닫기</translation>
+    </message>
+</context>
 <context>
     <name>SettingsPage</name>
     <message>
         <source>Reset to default</source>
-        <translation type="vanished">기본값으로 재설정</translation>
+        <translation>기본값으로 재설정</translation>
     </message>
 </context>
 <context>
@@ -2477,7 +2597,7 @@ The second line should be &quot;Mesh [Input bit depth] [Output bit depth]&quot;<
     <name>SpecialStyleChooserPage</name>
     <message>
         <source>Plain color</source>
-        <translation type="vanished">일반 색상</translation>
+        <translation>일반 색상</translation>
     </message>
 </context>
 <context>
@@ -2496,7 +2616,7 @@ The second line should be &quot;Mesh [Input bit depth] [Output bit depth]&quot;<
     </message>
     <message>
         <source>Last Speed:</source>
-        <translation>마지막 속도</translation>
+        <translation>마지막 속도:</translation>
     </message>
     <message>
         <source>---</source>
@@ -2671,7 +2791,7 @@ Are you sure ?</source>
     </message>
     <message>
         <source>Show or hide parts of the Color Page.</source>
-        <translation>색 페이지의 일부 표시 또는 숨기기</translation>
+        <translation>색 페이지의 일부 표시 또는 숨기기.</translation>
     </message>
     <message>
         <source>Wheel</source>
@@ -2691,7 +2811,7 @@ Are you sure ?</source>
     </message>
     <message>
         <source>Toggle orientation of the Color Page.</source>
-        <translation type="vanished">색상 페이지의 방향 전환</translation>
+        <translation>색상 페이지의 방향 전환.</translation>
     </message>
     <message>
         <source>Auto</source>
@@ -2747,19 +2867,19 @@ Are you sure ?</source>
     </message>
     <message>
         <source>Style Editor - No Valid Style Selected</source>
-        <translation>스타일 편집기 - 유효한 스타일이 선택되지 않음.</translation>
+        <translation>스타일 편집기 - 유효한 스타일이 선택되지 않음</translation>
     </message>
     <message>
         <source>[CLEANUP]  </source>
-        <translation type="vanished">[정리]</translation>
+        <translation>[정리]</translation>
     </message>
     <message>
         <source>[STUDIO]  </source>
-        <translation type="vanished">[스튜디오]</translation>
+        <translation>[스튜디오]</translation>
     </message>
     <message>
         <source>[LEVEL]  </source>
-        <translation type="vanished">[레벨]</translation>
+        <translation>[레벨]</translation>
     </message>
     <message>
         <source>Cleanup </source>
@@ -2797,6 +2917,14 @@ Are you sure ?</source>
         <source>Hex Color Names...</source>
         <translation>16진수 색상 이름...</translation>
     </message>
+    <message>
+        <source>Search</source>
+        <translation>검색</translation>
+    </message>
+    <message>
+        <source>Clear Search</source>
+        <translation>검색 삭제</translation>
+    </message>
 </context>
 <context>
     <name>StyleEditorGUI::ColorChannelControl</name>
@@ -2840,11 +2968,26 @@ Are you sure ?</source>
         <translation>기본값으로 재설정</translation>
     </message>
 </context>
+<context>
+    <name>StyleEditorGUI::StyleChooserPage</name>
+    <message>
+        <source>Pin To Top</source>
+        <translation>맨 위로 고정</translation>
+    </message>
+    <message>
+        <source>Set Pins To Top</source>
+        <translation>핀을 상단으로 설정</translation>
+    </message>
+    <message>
+        <source>Clear Pins To Top</source>
+        <translation>핀을 위로 지우기</translation>
+    </message>
+</context>
 <context>
     <name>StyleIndexLineEdit</name>
     <message>
         <source>current</source>
-        <translation type="vanished">현재</translation>
+        <translation>현재</translation>
     </message>
 </context>
 <context>
@@ -2927,14 +3070,14 @@ Are you sure ?</source>
     <name>ToneCurveField</name>
     <message>
         <source>Channel:</source>
-        <translation type="vanished">채널:</translation>
+        <translation>채널:</translation>
     </message>
 </context>
 <context>
     <name>VectorBrushStyleChooserPage</name>
     <message>
         <source>Plain color</source>
-        <translation type="vanished">일반 색상</translation>
+        <translation>일반 색상</translation>
     </message>
 </context>
 <context>
