@@ -1,6 +1,24 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="es_UY">
+<context>
+    <name>APngWriterProperties</name>
+    <message>
+        <location filename="../../image/ffmpeg/tiio_apng.cpp" line="225"/>
+        <source>Scale</source>
+        <translation>Escala</translation>
+    </message>
+    <message>
+        <location filename="../../image/ffmpeg/tiio_apng.cpp" line="226"/>
+        <source>Looping</source>
+        <translation>Cíclico</translation>
+    </message>
+    <message>
+        <location filename="../../image/ffmpeg/tiio_apng.cpp" line="227"/>
+        <source>Write as .png</source>
+        <translation>Guardar como .png</translation>
+    </message>
+</context>
 <context>
     <name>AviWriterProperties</name>
     <message>
@@ -17,66 +35,94 @@
 <context>
     <name>ExrWriterProperties</name>
     <message>
-        <location filename="../../image/exr/tiio_exr.cpp" line="227"/>
+        <location filename="../../image/exr/tiio_exr.cpp" line="290"/>
         <source>Bits Per Pixel</source>
         <translatorcomment>Bits por píxel</translatorcomment>
         <translation>Bits por píxel</translation>
     </message>
     <message>
-        <location filename="../../image/exr/tiio_exr.cpp" line="228"/>
+        <location filename="../../image/exr/tiio_exr.cpp" line="292"/>
         <source>48(RGB Half Float)</source>
         <translation>48 (color decimal medio)</translation>
     </message>
     <message>
-        <location filename="../../image/exr/tiio_exr.cpp" line="229"/>
+        <location filename="../../image/exr/tiio_exr.cpp" line="293"/>
         <source>64(RGBA Half Float)</source>
         <translation>64 (color + alfa decimal medio)</translation>
     </message>
     <message>
-        <location filename="../../image/exr/tiio_exr.cpp" line="231"/>
+        <location filename="../../image/exr/tiio_exr.cpp" line="294"/>
+        <source>96(RGB Float)</source>
+        <translation>96 (color decimal)</translation>
+    </message>
+    <message>
+        <location filename="../../image/exr/tiio_exr.cpp" line="295"/>
+        <source>128(RGBA Float)</source>
+        <translation>128 (color + alfa decimal)</translation>
+    </message>
+    <message>
+        <location filename="../../image/exr/tiio_exr.cpp" line="299"/>
         <source>Compression Type</source>
         <translation>Tipo de compresión</translation>
     </message>
     <message>
-        <location filename="../../image/exr/tiio_exr.cpp" line="233"/>
+        <location filename="../../image/exr/tiio_exr.cpp" line="301"/>
         <source>No compression</source>
         <translation>Sin compresión</translation>
     </message>
     <message>
-        <location filename="../../image/exr/tiio_exr.cpp" line="236"/>
+        <location filename="../../image/exr/tiio_exr.cpp" line="304"/>
         <source>Run Length Encoding (RLE)</source>
         <translation>Compresión Run Length (RLE)</translation>
     </message>
     <message>
-        <location filename="../../image/exr/tiio_exr.cpp" line="239"/>
+        <location filename="../../image/exr/tiio_exr.cpp" line="307"/>
         <source>ZIP compression per Scanline (ZIPS)</source>
         <translation>Compresión ZIP por línea de barrido (ZIPS)</translation>
     </message>
     <message>
-        <location filename="../../image/exr/tiio_exr.cpp" line="242"/>
+        <location filename="../../image/exr/tiio_exr.cpp" line="310"/>
         <source>ZIP compression per scanline band (ZIP)</source>
         <translation>Compresión ZIP por banda de línea de barrido (ZIP)</translation>
     </message>
     <message>
-        <location filename="../../image/exr/tiio_exr.cpp" line="245"/>
+        <location filename="../../image/exr/tiio_exr.cpp" line="313"/>
         <source>PIZ-based wavelet compression (PIZ)</source>
         <translation>Compresión de ondículas basada en PIZ (PIZ)</translation>
     </message>
     <message>
-        <location filename="../../image/exr/tiio_exr.cpp" line="247"/>
+        <location filename="../../image/exr/tiio_exr.cpp" line="315"/>
         <source>Storage Type</source>
         <translation>Tipo de almacenamiento</translation>
     </message>
     <message>
-        <location filename="../../image/exr/tiio_exr.cpp" line="248"/>
+        <location filename="../../image/exr/tiio_exr.cpp" line="316"/>
         <source>Scan-line based</source>
         <translation>Basado en líneas de barrido</translation>
     </message>
     <message>
-        <location filename="../../image/exr/tiio_exr.cpp" line="249"/>
+        <location filename="../../image/exr/tiio_exr.cpp" line="317"/>
         <source>Tile based</source>
         <translation>Basado en celdas</translation>
     </message>
+    <message>
+        <location filename="../../image/exr/tiio_exr.cpp" line="319"/>
+        <source>Color Space Gamma</source>
+        <translation>Gama del espacio de color</translation>
+    </message>
+</context>
+<context>
+    <name>FFMovWriterProperties</name>
+    <message>
+        <location filename="../../image/ffmpeg/tiio_ff_mov.cpp" line="234"/>
+        <source>Quality</source>
+        <translation>Calidad</translation>
+    </message>
+    <message>
+        <location filename="../../image/ffmpeg/tiio_ff_mov.cpp" line="235"/>
+        <source>Scale</source>
+        <translation>Escala</translation>
+    </message>
 </context>
 <context>
     <name>GifWriterProperties</name>
@@ -194,12 +240,13 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../../image/ffmpeg/tiio_ffmpeg.cpp" line="213"/>
+        <location filename="../../image/ffmpeg/tiio_ffmpeg.cpp" line="172"/>
         <source>FFmpeg returned error-code: %1</source>
         <translation>Código de error devuelto por FFmpeg: %1</translation>
     </message>
     <message>
-        <location filename="../../image/ffmpeg/tiio_ffmpeg.cpp" line="217"/>
+        <location filename="../../image/ffmpeg/tiio_ffmpeg.cpp" line="160"/>
+        <location filename="../../image/ffmpeg/tiio_ffmpeg.cpp" line="176"/>
         <source>FFmpeg timed out.
 Please check the file for errors.
 If the file doesn&apos;t play or is incomplete, 
@@ -244,7 +291,7 @@ intentar aumentar el tiempo de espera en las Preferencias.</translation>
     </message>
     <message>
         <location filename="../../image/sgi/filesgi.cpp" line="1235"/>
-        <source>Endianess</source>
+        <source>Endianness</source>
         <translation>Orden</translation>
     </message>
     <message>
