@@ -87,6 +87,23 @@
         <source>Table</source>
         <translation>Mesa</translation>
     </message>
+    <message>
+        <source>Flip Object Horizontally</source>
+        <translatorcomment>Invertir objeto horizontalmente</translatorcomment>
+        <translation></translation>
+    </message>
+    <message>
+        <source>Flip Object Vertically</source>
+        <translation>Invertir objeto verticalmente</translation>
+    </message>
+    <message>
+        <source>Rotate Object Left</source>
+        <translation>Rotar objeto en sentido antihorario</translation>
+    </message>
+    <message>
+        <source>Rotate Object Right</source>
+        <translation>Rotar objeto en sentido horario</translation>
+    </message>
 </context>
 <context>
     <name>BrushTool</name>
@@ -270,7 +287,7 @@
     </message>
     <message>
         <source>Rectangular</source>
-        <translation>Rectangular</translation>
+        <translation>Marco</translation>
     </message>
     <message>
         <source>Freehand</source>
@@ -474,7 +491,7 @@
     </message>
     <message>
         <source>Rectangular</source>
-        <translation>Rectangular</translation>
+        <translation>Marco</translation>
     </message>
     <message>
         <source>Freehand</source>
@@ -557,7 +574,7 @@
     </message>
     <message>
         <source>Rectangular</source>
-        <translation>Rectangular</translation>
+        <translation>Marco</translation>
     </message>
     <message>
         <source>Freehand</source>
@@ -583,6 +600,10 @@
         <source>Maximum Gap</source>
         <translation>Hueco máximo</translation>
     </message>
+    <message>
+        <source>Pick+Freehand</source>
+        <translation>Escoger+Lazo</translation>
+    </message>
 </context>
 <context>
     <name>FingerTool</name>
@@ -674,7 +695,7 @@
     </message>
     <message>
         <source>Rectangular</source>
-        <translation>Rectangular</translation>
+        <translation>Marco</translation>
     </message>
     <message>
         <source>Freehand</source>
@@ -1286,7 +1307,7 @@ Do you want to proceed?</source>
     </message>
     <message>
         <source>Rectangular</source>
-        <translation>Rectangular</translation>
+        <translation>Marco</translation>
     </message>
     <message>
         <source>Freehand</source>
@@ -1347,7 +1368,7 @@ Do you want to proceed?</source>
     </message>
     <message>
         <source>Rectangular</source>
-        <translation>Rectangular</translation>
+        <translation>Marco</translation>
     </message>
     <message>
         <source>Freehand</source>
@@ -1417,7 +1438,7 @@ Do you want to proceed?</source>
     </message>
     <message>
         <source>Rectangular</source>
-        <translation>Rectangular</translation>
+        <translation>Marco</translation>
     </message>
     <message>
         <source>Freehand</source>
@@ -1466,6 +1487,22 @@ Do you want to proceed?</source>
         <source>Position</source>
         <translation>Posición</translation>
     </message>
+    <message>
+        <source>Flip Selection Horizontally</source>
+        <translation>Invertir selección horizontalmente</translation>
+    </message>
+    <message>
+        <source>Flip Selection Vertically</source>
+        <translation>Invertir selección verticalmente</translation>
+    </message>
+    <message>
+        <source>Rotate Selection Left</source>
+        <translation>Rotar selección en sentido antihorario</translation>
+    </message>
+    <message>
+        <source>Rotate Selection Right</source>
+        <translation>Rotar selección en sentido horario</translation>
+    </message>
 </context>
 <context>
     <name>ShiftTraceToolOptionBox</name>
@@ -1888,7 +1925,7 @@ movido hacia el final de la primera página de la paleta.</translation>
     </message>
     <message>
         <source>Rectangular</source>
-        <translation>Rectangular</translation>
+        <translation>Marco</translation>
     </message>
 </context>
 <context>
